"""
This file is automatically generated.

Do not modify.
"""
import sys
import functools
import warnings
import json

try:
    from typing import List
    from ceph.mon_command_api import CommandResult
except ImportError:
    pass

if sys.version_info > (3, 0):
    from typing import overload


def deprecated(func):
    @functools.wraps(func)
    def new_func(*args, **kwargs):
        warnings.simplefilter('always', DeprecationWarning)  # turn off filter
        warnings.warn("Call to deprecated function {}.".format(func.__name__),
                      category=DeprecationWarning,
                      stacklevel=2)
        warnings.simplefilter('default', DeprecationWarning)  # reset filter
        return func(*args, **kwargs)
    return new_func


class MonCommandApi(object):
    """
    MonCommandApi is a class that provides access to the whole Ceph command line API in a 
    type save way. 
    
    Usage:
    
    >>> import rados
    ... from ceph_command_api import MonCommandApi
    ... cluster = rados.Rados(conffile='/etc/ceph/ceph.conf')
    ... cluster.connect()
    ... print(MonCommandApi(cluster).version())
    """
    def __init__(self, rados):
        self._rados = rados
        
    def _mon_command(self, cmd, inbuf=b'', target=None):
        res = self._rados.mon_command(json.dumps(cmd), inbuf=inbuf, target=target)
        return CommandResult(*res)
    
    def ansible_set_ssl_certificate(self, mgr_id: str=None):
        """
        Prefix: ``ansible set-ssl-certificate``
        
        module=mgr perm=w flags=mgr
        
        :param mgr_id:
        """
        prefix = 'ansible set-ssl-certificate'
        _args = {'prefix': prefix, 'mgr_id': mgr_id}
        return self._mon_command(_args)
    
    def ansible_set_ssl_certificate_key(self, mgr_id: str=None):
        """
        Prefix: ``ansible set-ssl-certificate-key``
        
        module=mgr perm=w flags=mgr
        
        :param mgr_id:
        """
        prefix = 'ansible set-ssl-certificate-key'
        _args = {'prefix': prefix, 'mgr_id': mgr_id}
        return self._mon_command(_args)
    
    def auth_add(self, entity: str, caps: List[str]=None):
        """
        Prefix: ``auth add``
        
        add auth info for <entity> from input file, or random key if no input
        is given, and/or any caps specified in the command
        
        module=auth perm=rwx flags=
        
        :param entity:
        :param caps:
        """
        prefix = 'auth add'
        _args = {'prefix': prefix, 'entity': entity, 'caps': caps}
        return self._mon_command(_args)
    
    def auth_caps(self, entity: str, caps: List[str]):
        """
        Prefix: ``auth caps``
        
        update caps for <name> from caps specified in the command
        
        module=auth perm=rwx flags=
        
        :param entity:
        :param caps:
        """
        prefix = 'auth caps'
        _args = {'prefix': prefix, 'entity': entity, 'caps': caps}
        return self._mon_command(_args)
    
    @deprecated
    def auth_del(self, entity: str):
        """
        Prefix: ``auth del``
        
        delete all caps for <name>
        
        module=auth perm=rwx flags=deprecated
        
        :param entity:
        """
        prefix = 'auth del'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def auth_export(self, entity: str=None):
        """
        Prefix: ``auth export``
        
        write keyring for requested entity, or master keyring if none given
        
        module=auth perm=rx flags=
        
        :param entity:
        """
        prefix = 'auth export'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def auth_get(self, entity: str):
        """
        Prefix: ``auth get``
        
        write keyring file with requested key
        
        module=auth perm=rx flags=
        
        :param entity:
        """
        prefix = 'auth get'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def auth_get_key(self, entity: str):
        """
        Prefix: ``auth get-key``
        
        display requested key
        
        module=auth perm=rx flags=
        
        :param entity:
        """
        prefix = 'auth get-key'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def auth_get_or_create(self, entity: str, caps: List[str]=None):
        """
        Prefix: ``auth get-or-create``
        
        add auth info for <entity> from input file, or random key if no input
        given, and/or any caps specified in the command
        
        module=auth perm=rwx flags=
        
        :param entity:
        :param caps:
        """
        prefix = 'auth get-or-create'
        _args = {'prefix': prefix, 'entity': entity, 'caps': caps}
        return self._mon_command(_args)
    
    def auth_get_or_create_key(self, entity: str, caps: List[str]=None):
        """
        Prefix: ``auth get-or-create-key``
        
        get, or add, key for <name> from system/caps pairs specified in the
        command.  If key already exists, any given caps must match the
        existing caps for that key.
        
        module=auth perm=rwx flags=
        
        :param entity:
        :param caps:
        """
        prefix = 'auth get-or-create-key'
        _args = {'prefix': prefix, 'entity': entity, 'caps': caps}
        return self._mon_command(_args)
    
    def auth_import(self):
        """
        Prefix: ``auth import``
        
        auth import: read keyring file from -i <file>
        
        module=auth perm=rwx flags=
        """
        prefix = 'auth import'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def auth_list(self):
        """
        Prefix: ``auth list``
        
        list authentication state
        
        module=auth perm=rx flags=deprecated
        """
        prefix = 'auth list'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def auth_ls(self):
        """
        Prefix: ``auth ls``
        
        list authentication state
        
        module=auth perm=rx flags=
        """
        prefix = 'auth ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @overload  # Python 3 only
    def auth_print_key(self, entity: str):
        """
        Prefix: ``auth print-key``
        
        display requested key
        
        module=auth perm=rx flags=
        
        :param entity:
        """
        prefix = 'auth print-key'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    @overload  # Python 3 only
    def auth_print_key(self, entity: str):
        """
        Prefix: ``auth print_key``
        
        display requested key
        
        module=auth perm=rx flags=
        
        :param entity:
        """
        prefix = 'auth print_key'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def auth_rm(self, entity: str):
        """
        Prefix: ``auth rm``
        
        remove all caps for <name>
        
        module=auth perm=rwx flags=
        
        :param entity:
        """
        prefix = 'auth rm'
        _args = {'prefix': prefix, 'entity': entity}
        return self._mon_command(_args)
    
    def balancer_dump(self, plan: str):
        """
        Prefix: ``balancer dump``
        
        Show an optimization plan
        
        module=mgr perm=r flags=mgr
        
        :param plan:
        """
        prefix = 'balancer dump'
        _args = {'prefix': prefix, 'plan': plan}
        return self._mon_command(_args)
    
    def balancer_eval(self, option: str=None):
        """
        Prefix: ``balancer eval``
        
        Evaluate data distribution for the current cluster or specific pool or
        specific plan
        
        module=mgr perm=r flags=mgr
        
        :param option:
        """
        prefix = 'balancer eval'
        _args = {'prefix': prefix, 'option': option}
        return self._mon_command(_args)
    
    def balancer_eval_verbose(self, option: str=None):
        """
        Prefix: ``balancer eval-verbose``
        
        Evaluate data distribution for the current cluster or specific pool or
        specific plan (verbosely)
        
        module=mgr perm=r flags=mgr
        
        :param option:
        """
        prefix = 'balancer eval-verbose'
        _args = {'prefix': prefix, 'option': option}
        return self._mon_command(_args)
    
    def balancer_execute(self, plan: str):
        """
        Prefix: ``balancer execute``
        
        Execute an optimization plan
        
        module=mgr perm=rw flags=mgr
        
        :param plan:
        """
        prefix = 'balancer execute'
        _args = {'prefix': prefix, 'plan': plan}
        return self._mon_command(_args)
    
    def balancer_ls(self):
        """
        Prefix: ``balancer ls``
        
        List all plans
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'balancer ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def balancer_mode(self, mode: str):
        """
        Prefix: ``balancer mode``
        
        Set balancer mode
        
        module=mgr perm=rw flags=mgr
        
        :param mode: CephChoices strings=none|crush-compat|upmap
        """
        prefix = 'balancer mode'
        _args = {'prefix': prefix, 'mode': mode}
        return self._mon_command(_args)
    
    def balancer_off(self):
        """
        Prefix: ``balancer off``
        
        Disable automatic balancing
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'balancer off'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def balancer_on(self):
        """
        Prefix: ``balancer on``
        
        Enable automatic balancing
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'balancer on'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def balancer_optimize(self, plan: str, pools: List[str]=None):
        """
        Prefix: ``balancer optimize``
        
        Run optimizer to create a new plan
        
        module=mgr perm=rw flags=mgr
        
        :param plan:
        :param pools:
        """
        prefix = 'balancer optimize'
        _args = {'prefix': prefix, 'plan': plan, 'pools': pools}
        return self._mon_command(_args)
    
    def balancer_pool_add(self, pools: List[str]):
        """
        Prefix: ``balancer pool add``
        
        Enable automatic balancing for specific pools
        
        module=mgr perm=rw flags=mgr
        
        :param pools:
        """
        prefix = 'balancer pool add'
        _args = {'prefix': prefix, 'pools': pools}
        return self._mon_command(_args)
    
    def balancer_pool_ls(self):
        """
        Prefix: ``balancer pool ls``
        
        List automatic balancing pools. Note that empty list means all
        existing pools will be automatic balancing targets, which is the
        default behaviour of balancer.
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'balancer pool ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def balancer_pool_rm(self, pools: List[str]):
        """
        Prefix: ``balancer pool rm``
        
        Disable automatic balancing for specific pools
        
        module=mgr perm=rw flags=mgr
        
        :param pools:
        """
        prefix = 'balancer pool rm'
        _args = {'prefix': prefix, 'pools': pools}
        return self._mon_command(_args)
    
    def balancer_reset(self):
        """
        Prefix: ``balancer reset``
        
        Discard all optimization plans
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'balancer reset'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def balancer_rm(self, plan: str):
        """
        Prefix: ``balancer rm``
        
        Discard an optimization plan
        
        module=mgr perm=rw flags=mgr
        
        :param plan:
        """
        prefix = 'balancer rm'
        _args = {'prefix': prefix, 'plan': plan}
        return self._mon_command(_args)
    
    def balancer_show(self, plan: str):
        """
        Prefix: ``balancer show``
        
        Show details of an optimization plan
        
        module=mgr perm=r flags=mgr
        
        :param plan:
        """
        prefix = 'balancer show'
        _args = {'prefix': prefix, 'plan': plan}
        return self._mon_command(_args)
    
    def balancer_status(self):
        """
        Prefix: ``balancer status``
        
        Show balancer status
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'balancer status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def compact(self):
        """
        Prefix: ``compact``
        
        cause compaction of monitor's leveldb/rocksdb storage
        
        module=mon perm=rw flags=no_forward, deprecated
        """
        prefix = 'compact'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_assimilate_conf(self):
        """
        Prefix: ``config assimilate-conf``
        
        Assimilate options from a conf, and return a new, minimal conf file
        
        module=config perm=rw flags=
        """
        prefix = 'config assimilate-conf'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_dump(self):
        """
        Prefix: ``config dump``
        
        Show all configuration option(s)
        
        module=mon perm=r flags=
        """
        prefix = 'config dump'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_generate_minimal_conf(self):
        """
        Prefix: ``config generate-minimal-conf``
        
        Generate a minimal ceph.conf file
        
        module=config perm=r flags=
        """
        prefix = 'config generate-minimal-conf'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_get(self, who: str, key: str):
        """
        Prefix: ``config get``
        
        Show configuration option(s) for an entity
        
        module=config perm=r flags=
        
        :param who:
        :param key:
        """
        prefix = 'config get'
        _args = {'prefix': prefix, 'who': who, 'key': key}
        return self._mon_command(_args)
    
    def config_help(self, key: str):
        """
        Prefix: ``config help``
        
        Describe a configuration option
        
        module=config perm=r flags=
        
        :param key:
        """
        prefix = 'config help'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def config_log(self, num: int):
        """
        Prefix: ``config log``
        
        Show recent history of config changes
        
        module=config perm=r flags=
        
        :param num: CephInt
        """
        prefix = 'config log'
        _args = {'prefix': prefix, 'num': num}
        return self._mon_command(_args)
    
    def config_ls(self):
        """
        Prefix: ``config ls``
        
        List available configuration options
        
        module=config perm=r flags=
        """
        prefix = 'config ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_reset(self, num: int):
        """
        Prefix: ``config reset``
        
        Revert configuration to a historical version specified by <num>
        
        module=config perm=rw flags=
        
        :param num: CephInt range= ``0``
        """
        prefix = 'config reset'
        _args = {'prefix': prefix, 'num': num}
        return self._mon_command(_args)
    
    def config_rm(self, who: str, name: str):
        """
        Prefix: ``config rm``
        
        Clear a configuration option for one or more entities
        
        module=config perm=rw flags=
        
        :param who:
        :param name:
        """
        prefix = 'config rm'
        _args = {'prefix': prefix, 'who': who, 'name': name}
        return self._mon_command(_args)
    
    def config_set(self, who: str, name: str, value: str, force: bool=None):
        """
        Prefix: ``config set``
        
        Set a configuration option for one or more entities
        
        module=config perm=rw flags=
        
        :param who:
        :param name:
        :param value:
        :param force: CephBool
        """
        prefix = 'config set'
        _args = {'prefix': prefix, 'who': who, 'name': name, 'value': value, 'force': force}
        return self._mon_command(_args)
    
    def config_show(self, who: str, key: str):
        """
        Prefix: ``config show``
        
        Show running configuration
        
        module=mgr perm=r flags=mgr
        
        :param who:
        :param key:
        """
        prefix = 'config show'
        _args = {'prefix': prefix, 'who': who, 'key': key}
        return self._mon_command(_args)
    
    def config_show_with_defaults(self, who: str):
        """
        Prefix: ``config show-with-defaults``
        
        Show running configuration (including compiled-in defaults)
        
        module=mgr perm=r flags=mgr
        
        :param who:
        """
        prefix = 'config show-with-defaults'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    @deprecated
    def config_key_del(self, key: str):
        """
        Prefix: ``config-key del``
        
        delete <key>
        
        module=config-key perm=rw flags=deprecated
        
        :param key:
        """
        prefix = 'config-key del'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def config_key_dump(self, key: str=None):
        """
        Prefix: ``config-key dump``
        
        dump keys and values (with optional prefix)
        
        module=config-key perm=r flags=
        
        :param key:
        """
        prefix = 'config-key dump'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def config_key_exists(self, key: str):
        """
        Prefix: ``config-key exists``
        
        check for <key>'s existence
        
        module=config-key perm=r flags=
        
        :param key:
        """
        prefix = 'config-key exists'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def config_key_get(self, key: str):
        """
        Prefix: ``config-key get``
        
        get <key>
        
        module=config-key perm=r flags=
        
        :param key:
        """
        prefix = 'config-key get'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    @deprecated
    def config_key_list(self):
        """
        Prefix: ``config-key list``
        
        list keys
        
        module=config-key perm=r flags=deprecated
        """
        prefix = 'config-key list'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def config_key_ls(self):
        """
        Prefix: ``config-key ls``
        
        list keys
        
        module=config-key perm=r flags=
        """
        prefix = 'config-key ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def config_key_put(self, key: str, val: str=None):
        """
        Prefix: ``config-key put``
        
        put <key>, value <val>
        
        module=config-key perm=rw flags=deprecated
        
        :param key:
        :param val:
        """
        prefix = 'config-key put'
        _args = {'prefix': prefix, 'key': key, 'val': val}
        return self._mon_command(_args)
    
    def config_key_rm(self, key: str):
        """
        Prefix: ``config-key rm``
        
        rm <key>
        
        module=config-key perm=rw flags=
        
        :param key:
        """
        prefix = 'config-key rm'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def config_key_set(self, key: str, val: str=None):
        """
        Prefix: ``config-key set``
        
        set <key> to value <val>
        
        module=config-key perm=rw flags=
        
        :param key:
        :param val:
        """
        prefix = 'config-key set'
        _args = {'prefix': prefix, 'key': key, 'val': val}
        return self._mon_command(_args)
    
    def crash_info(self, id_1: str):
        """
        Prefix: ``crash info``
        
        show crash dump metadata
        
        module=mgr perm=r flags=mgr
        
        :param id_1: Real name is ``id``
        """
        prefix = 'crash info'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def crash_json_report(self, hours: str):
        """
        Prefix: ``crash json_report``
        
        Crashes in the last <hours> hours
        
        module=mgr perm=r flags=mgr
        
        :param hours:
        """
        prefix = 'crash json_report'
        _args = {'prefix': prefix, 'hours': hours}
        return self._mon_command(_args)
    
    def crash_ls(self):
        """
        Prefix: ``crash ls``
        
        Show saved crash dumps
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'crash ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def crash_post(self):
        """
        Prefix: ``crash post``
        
        Add a crash dump (use -i <jsonfile>)
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'crash post'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def crash_prune(self, keep: str):
        """
        Prefix: ``crash prune``
        
        Remove crashes older than <keep> days
        
        module=mgr perm=rw flags=mgr
        
        :param keep:
        """
        prefix = 'crash prune'
        _args = {'prefix': prefix, 'keep': keep}
        return self._mon_command(_args)
    
    def crash_rm(self, id_1: str):
        """
        Prefix: ``crash rm``
        
        Remove a saved crash <id>
        
        module=mgr perm=rw flags=mgr
        
        :param id_1: Real name is ``id``
        """
        prefix = 'crash rm'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def crash_stat(self):
        """
        Prefix: ``crash stat``
        
        Summarize recorded crashes
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'crash stat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_ac_role_add_scope_perms(self, rolename: str, scopename: str, permissions: List[str]):
        """
        Prefix: ``dashboard ac-role-add-scope-perms``
        
        Add the scope permissions for a role
        
        module=mgr perm=w flags=mgr
        
        :param rolename:
        :param scopename:
        :param permissions:
        """
        prefix = 'dashboard ac-role-add-scope-perms'
        _args = {'prefix': prefix, 'rolename': rolename, 'scopename': scopename, 'permissions':
                 permissions}
        return self._mon_command(_args)
    
    def dashboard_ac_role_create(self, rolename: str, description: str=None):
        """
        Prefix: ``dashboard ac-role-create``
        
        Create a new access control role
        
        module=mgr perm=w flags=mgr
        
        :param rolename:
        :param description:
        """
        prefix = 'dashboard ac-role-create'
        _args = {'prefix': prefix, 'rolename': rolename, 'description': description}
        return self._mon_command(_args)
    
    def dashboard_ac_role_del_scope_perms(self, rolename: str, scopename: str):
        """
        Prefix: ``dashboard ac-role-del-scope-perms``
        
        Delete the scope permissions for a role
        
        module=mgr perm=w flags=mgr
        
        :param rolename:
        :param scopename:
        """
        prefix = 'dashboard ac-role-del-scope-perms'
        _args = {'prefix': prefix, 'rolename': rolename, 'scopename': scopename}
        return self._mon_command(_args)
    
    def dashboard_ac_role_delete(self, rolename: str):
        """
        Prefix: ``dashboard ac-role-delete``
        
        Delete an access control role
        
        module=mgr perm=w flags=mgr
        
        :param rolename:
        """
        prefix = 'dashboard ac-role-delete'
        _args = {'prefix': prefix, 'rolename': rolename}
        return self._mon_command(_args)
    
    def dashboard_ac_role_show(self, rolename: str=None):
        """
        Prefix: ``dashboard ac-role-show``
        
        Show role info
        
        module=mgr perm=r flags=mgr
        
        :param rolename:
        """
        prefix = 'dashboard ac-role-show'
        _args = {'prefix': prefix, 'rolename': rolename}
        return self._mon_command(_args)
    
    def dashboard_ac_user_add_roles(self, username: str, roles: List[str]):
        """
        Prefix: ``dashboard ac-user-add-roles``
        
        Add roles to user
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param roles:
        """
        prefix = 'dashboard ac-user-add-roles'
        _args = {'prefix': prefix, 'username': username, 'roles': roles}
        return self._mon_command(_args)
    
    def dashboard_ac_user_create(self, username: str, password: str=None, rolename: str=None,
                                 name: str=None, email: str=None):
        """
        Prefix: ``dashboard ac-user-create``
        
        Create a user
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param password:
        :param rolename:
        :param name:
        :param email:
        """
        prefix = 'dashboard ac-user-create'
        _args = {'prefix': prefix, 'username': username, 'password': password, 'rolename':
                 rolename, 'name': name, 'email': email}
        return self._mon_command(_args)
    
    def dashboard_ac_user_del_roles(self, username: str, roles: List[str]):
        """
        Prefix: ``dashboard ac-user-del-roles``
        
        Delete roles from user
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param roles:
        """
        prefix = 'dashboard ac-user-del-roles'
        _args = {'prefix': prefix, 'username': username, 'roles': roles}
        return self._mon_command(_args)
    
    def dashboard_ac_user_delete(self, username: str):
        """
        Prefix: ``dashboard ac-user-delete``
        
        Delete user
        
        module=mgr perm=w flags=mgr
        
        :param username:
        """
        prefix = 'dashboard ac-user-delete'
        _args = {'prefix': prefix, 'username': username}
        return self._mon_command(_args)
    
    def dashboard_ac_user_set_info(self, username: str, name: str, email: str):
        """
        Prefix: ``dashboard ac-user-set-info``
        
        Set user info
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param name:
        :param email:
        """
        prefix = 'dashboard ac-user-set-info'
        _args = {'prefix': prefix, 'username': username, 'name': name, 'email': email}
        return self._mon_command(_args)
    
    def dashboard_ac_user_set_password(self, username: str, password: str):
        """
        Prefix: ``dashboard ac-user-set-password``
        
        Set user password
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param password:
        """
        prefix = 'dashboard ac-user-set-password'
        _args = {'prefix': prefix, 'username': username, 'password': password}
        return self._mon_command(_args)
    
    def dashboard_ac_user_set_roles(self, username: str, roles: List[str]):
        """
        Prefix: ``dashboard ac-user-set-roles``
        
        Set user roles
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param roles:
        """
        prefix = 'dashboard ac-user-set-roles'
        _args = {'prefix': prefix, 'username': username, 'roles': roles}
        return self._mon_command(_args)
    
    def dashboard_ac_user_show(self, username: str=None):
        """
        Prefix: ``dashboard ac-user-show``
        
        Show user info
        
        module=mgr perm=r flags=mgr
        
        :param username:
        """
        prefix = 'dashboard ac-user-show'
        _args = {'prefix': prefix, 'username': username}
        return self._mon_command(_args)
    
    def dashboard_create_self_signed_cert(self):
        """
        Prefix: ``dashboard create-self-signed-cert``
        
        Create self signed certificate
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard create-self-signed-cert'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_feature(self, action: str, features: List[str]=None):
        """
        Prefix: ``dashboard feature``
        
        Enable or disable features in Ceph-Mgr Dashboard
        
        module=mgr perm=rw flags=mgr
        
        :param action: CephChoices strings=enable|disable|status
        :param features: CephChoices strings=rbd|mirroring|iscsi|cephfs|rgw
        """
        prefix = 'dashboard feature'
        _args = {'prefix': prefix, 'action': action, 'features': features}
        return self._mon_command(_args)
    
    def dashboard_get_alertmanager_api_host(self):
        """
        Prefix: ``dashboard get-alertmanager-api-host``
        
        Get the ALERTMANAGER_API_HOST option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-alertmanager-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_audit_api_enabled(self):
        """
        Prefix: ``dashboard get-audit-api-enabled``
        
        Get the AUDIT_API_ENABLED option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-audit-api-enabled'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_audit_api_log_payload(self):
        """
        Prefix: ``dashboard get-audit-api-log-payload``
        
        Get the AUDIT_API_LOG_PAYLOAD option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-audit-api-log-payload'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_enable_browsable_api(self):
        """
        Prefix: ``dashboard get-enable-browsable-api``
        
        Get the ENABLE_BROWSABLE_API option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-enable-browsable-api'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_ganesha_clusters_rados_pool_namespace(self):
        """
        Prefix: ``dashboard get-ganesha-clusters-rados-pool-namespace``
        
        Get the GANESHA_CLUSTERS_RADOS_POOL_NAMESPACE option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-ganesha-clusters-rados-pool-namespace'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_grafana_api_password(self):
        """
        Prefix: ``dashboard get-grafana-api-password``
        
        Get the GRAFANA_API_PASSWORD option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-grafana-api-password'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_grafana_api_url(self):
        """
        Prefix: ``dashboard get-grafana-api-url``
        
        Get the GRAFANA_API_URL option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-grafana-api-url'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_grafana_api_username(self):
        """
        Prefix: ``dashboard get-grafana-api-username``
        
        Get the GRAFANA_API_USERNAME option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-grafana-api-username'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_grafana_update_dashboards(self):
        """
        Prefix: ``dashboard get-grafana-update-dashboards``
        
        Get the GRAFANA_UPDATE_DASHBOARDS option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-grafana-update-dashboards'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_iscsi_api_ssl_verification(self):
        """
        Prefix: ``dashboard get-iscsi-api-ssl-verification``
        
        Get the ISCSI_API_SSL_VERIFICATION option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-iscsi-api-ssl-verification'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_jwt_token_ttl(self):
        """
        Prefix: ``dashboard get-jwt-token-ttl``
        
        Get the JWT token TTL in seconds
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-jwt-token-ttl'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_prometheus_api_host(self):
        """
        Prefix: ``dashboard get-prometheus-api-host``
        
        Get the PROMETHEUS_API_HOST option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-prometheus-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rest_requests_timeout(self):
        """
        Prefix: ``dashboard get-rest-requests-timeout``
        
        Get the REST_REQUESTS_TIMEOUT option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rest-requests-timeout'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_access_key(self):
        """
        Prefix: ``dashboard get-rgw-api-access-key``
        
        Get the RGW_API_ACCESS_KEY option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-access-key'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_admin_resource(self):
        """
        Prefix: ``dashboard get-rgw-api-admin-resource``
        
        Get the RGW_API_ADMIN_RESOURCE option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-admin-resource'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_host(self):
        """
        Prefix: ``dashboard get-rgw-api-host``
        
        Get the RGW_API_HOST option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_port(self):
        """
        Prefix: ``dashboard get-rgw-api-port``
        
        Get the RGW_API_PORT option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-port'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_scheme(self):
        """
        Prefix: ``dashboard get-rgw-api-scheme``
        
        Get the RGW_API_SCHEME option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-scheme'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_secret_key(self):
        """
        Prefix: ``dashboard get-rgw-api-secret-key``
        
        Get the RGW_API_SECRET_KEY option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-secret-key'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_ssl_verify(self):
        """
        Prefix: ``dashboard get-rgw-api-ssl-verify``
        
        Get the RGW_API_SSL_VERIFY option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-ssl-verify'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_get_rgw_api_user_id(self):
        """
        Prefix: ``dashboard get-rgw-api-user-id``
        
        Get the RGW_API_USER_ID option value
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard get-rgw-api-user-id'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_grafana_dashboards_update(self):
        """
        Prefix: ``dashboard grafana dashboards update``
        
        Push dashboards to Grafana
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard grafana dashboards update'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_iscsi_gateway_add(self, service_url: str):
        """
        Prefix: ``dashboard iscsi-gateway-add``
        
        Add iSCSI gateway configuration
        
        module=mgr perm=w flags=mgr
        
        :param service_url:
        """
        prefix = 'dashboard iscsi-gateway-add'
        _args = {'prefix': prefix, 'service_url': service_url}
        return self._mon_command(_args)
    
    def dashboard_iscsi_gateway_list(self):
        """
        Prefix: ``dashboard iscsi-gateway-list``
        
        List iSCSI gateways
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard iscsi-gateway-list'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_iscsi_gateway_rm(self, name: str):
        """
        Prefix: ``dashboard iscsi-gateway-rm``
        
        Remove iSCSI gateway configuration
        
        module=mgr perm=w flags=mgr
        
        :param name:
        """
        prefix = 'dashboard iscsi-gateway-rm'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    def dashboard_reset_alertmanager_api_host(self):
        """
        Prefix: ``dashboard reset-alertmanager-api-host``
        
        Reset the ALERTMANAGER_API_HOST option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-alertmanager-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_audit_api_enabled(self):
        """
        Prefix: ``dashboard reset-audit-api-enabled``
        
        Reset the AUDIT_API_ENABLED option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-audit-api-enabled'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_audit_api_log_payload(self):
        """
        Prefix: ``dashboard reset-audit-api-log-payload``
        
        Reset the AUDIT_API_LOG_PAYLOAD option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-audit-api-log-payload'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_enable_browsable_api(self):
        """
        Prefix: ``dashboard reset-enable-browsable-api``
        
        Reset the ENABLE_BROWSABLE_API option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-enable-browsable-api'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_ganesha_clusters_rados_pool_namespace(self):
        """
        Prefix: ``dashboard reset-ganesha-clusters-rados-pool-namespace``
        
        Reset the GANESHA_CLUSTERS_RADOS_POOL_NAMESPACE option to its default
        value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-ganesha-clusters-rados-pool-namespace'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_grafana_api_password(self):
        """
        Prefix: ``dashboard reset-grafana-api-password``
        
        Reset the GRAFANA_API_PASSWORD option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-grafana-api-password'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_grafana_api_url(self):
        """
        Prefix: ``dashboard reset-grafana-api-url``
        
        Reset the GRAFANA_API_URL option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-grafana-api-url'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_grafana_api_username(self):
        """
        Prefix: ``dashboard reset-grafana-api-username``
        
        Reset the GRAFANA_API_USERNAME option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-grafana-api-username'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_grafana_update_dashboards(self):
        """
        Prefix: ``dashboard reset-grafana-update-dashboards``
        
        Reset the GRAFANA_UPDATE_DASHBOARDS option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-grafana-update-dashboards'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_iscsi_api_ssl_verification(self):
        """
        Prefix: ``dashboard reset-iscsi-api-ssl-verification``
        
        Reset the ISCSI_API_SSL_VERIFICATION option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-iscsi-api-ssl-verification'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_prometheus_api_host(self):
        """
        Prefix: ``dashboard reset-prometheus-api-host``
        
        Reset the PROMETHEUS_API_HOST option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-prometheus-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rest_requests_timeout(self):
        """
        Prefix: ``dashboard reset-rest-requests-timeout``
        
        Reset the REST_REQUESTS_TIMEOUT option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rest-requests-timeout'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_access_key(self):
        """
        Prefix: ``dashboard reset-rgw-api-access-key``
        
        Reset the RGW_API_ACCESS_KEY option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-access-key'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_admin_resource(self):
        """
        Prefix: ``dashboard reset-rgw-api-admin-resource``
        
        Reset the RGW_API_ADMIN_RESOURCE option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-admin-resource'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_host(self):
        """
        Prefix: ``dashboard reset-rgw-api-host``
        
        Reset the RGW_API_HOST option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-host'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_port(self):
        """
        Prefix: ``dashboard reset-rgw-api-port``
        
        Reset the RGW_API_PORT option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-port'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_scheme(self):
        """
        Prefix: ``dashboard reset-rgw-api-scheme``
        
        Reset the RGW_API_SCHEME option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-scheme'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_secret_key(self):
        """
        Prefix: ``dashboard reset-rgw-api-secret-key``
        
        Reset the RGW_API_SECRET_KEY option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-secret-key'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_ssl_verify(self):
        """
        Prefix: ``dashboard reset-rgw-api-ssl-verify``
        
        Reset the RGW_API_SSL_VERIFY option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-ssl-verify'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_reset_rgw_api_user_id(self):
        """
        Prefix: ``dashboard reset-rgw-api-user-id``
        
        Reset the RGW_API_USER_ID option to its default value
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard reset-rgw-api-user-id'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_set_alertmanager_api_host(self, value: str):
        """
        Prefix: ``dashboard set-alertmanager-api-host``
        
        Set the ALERTMANAGER_API_HOST option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-alertmanager-api-host'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_audit_api_enabled(self, value: str):
        """
        Prefix: ``dashboard set-audit-api-enabled``
        
        Set the AUDIT_API_ENABLED option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-audit-api-enabled'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_audit_api_log_payload(self, value: str):
        """
        Prefix: ``dashboard set-audit-api-log-payload``
        
        Set the AUDIT_API_LOG_PAYLOAD option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-audit-api-log-payload'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_enable_browsable_api(self, value: str):
        """
        Prefix: ``dashboard set-enable-browsable-api``
        
        Set the ENABLE_BROWSABLE_API option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-enable-browsable-api'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_ganesha_clusters_rados_pool_namespace(self, value: str):
        """
        Prefix: ``dashboard set-ganesha-clusters-rados-pool-namespace``
        
        Set the GANESHA_CLUSTERS_RADOS_POOL_NAMESPACE option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-ganesha-clusters-rados-pool-namespace'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_grafana_api_password(self, value: str):
        """
        Prefix: ``dashboard set-grafana-api-password``
        
        Set the GRAFANA_API_PASSWORD option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-grafana-api-password'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_grafana_api_url(self, value: str):
        """
        Prefix: ``dashboard set-grafana-api-url``
        
        Set the GRAFANA_API_URL option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-grafana-api-url'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_grafana_api_username(self, value: str):
        """
        Prefix: ``dashboard set-grafana-api-username``
        
        Set the GRAFANA_API_USERNAME option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-grafana-api-username'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_grafana_update_dashboards(self, value: str):
        """
        Prefix: ``dashboard set-grafana-update-dashboards``
        
        Set the GRAFANA_UPDATE_DASHBOARDS option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-grafana-update-dashboards'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_iscsi_api_ssl_verification(self, value: str):
        """
        Prefix: ``dashboard set-iscsi-api-ssl-verification``
        
        Set the ISCSI_API_SSL_VERIFICATION option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-iscsi-api-ssl-verification'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_jwt_token_ttl(self, seconds: int):
        """
        Prefix: ``dashboard set-jwt-token-ttl``
        
        Set the JWT token TTL in seconds
        
        module=mgr perm=w flags=mgr
        
        :param seconds: CephInt
        """
        prefix = 'dashboard set-jwt-token-ttl'
        _args = {'prefix': prefix, 'seconds': seconds}
        return self._mon_command(_args)
    
    def dashboard_set_login_credentials(self, username: str, password: str):
        """
        Prefix: ``dashboard set-login-credentials``
        
        Set the login credentials
        
        module=mgr perm=w flags=mgr
        
        :param username:
        :param password:
        """
        prefix = 'dashboard set-login-credentials'
        _args = {'prefix': prefix, 'username': username, 'password': password}
        return self._mon_command(_args)
    
    def dashboard_set_prometheus_api_host(self, value: str):
        """
        Prefix: ``dashboard set-prometheus-api-host``
        
        Set the PROMETHEUS_API_HOST option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-prometheus-api-host'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rest_requests_timeout(self, value: int):
        """
        Prefix: ``dashboard set-rest-requests-timeout``
        
        Set the REST_REQUESTS_TIMEOUT option value
        
        module=mgr perm=w flags=mgr
        
        :param value: CephInt
        """
        prefix = 'dashboard set-rest-requests-timeout'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_access_key(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-access-key``
        
        Set the RGW_API_ACCESS_KEY option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-access-key'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_admin_resource(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-admin-resource``
        
        Set the RGW_API_ADMIN_RESOURCE option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-admin-resource'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_host(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-host``
        
        Set the RGW_API_HOST option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-host'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_port(self, value: int):
        """
        Prefix: ``dashboard set-rgw-api-port``
        
        Set the RGW_API_PORT option value
        
        module=mgr perm=w flags=mgr
        
        :param value: CephInt
        """
        prefix = 'dashboard set-rgw-api-port'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_scheme(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-scheme``
        
        Set the RGW_API_SCHEME option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-scheme'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_secret_key(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-secret-key``
        
        Set the RGW_API_SECRET_KEY option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-secret-key'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_ssl_verify(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-ssl-verify``
        
        Set the RGW_API_SSL_VERIFY option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-ssl-verify'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_rgw_api_user_id(self, value: str):
        """
        Prefix: ``dashboard set-rgw-api-user-id``
        
        Set the RGW_API_USER_ID option value
        
        module=mgr perm=w flags=mgr
        
        :param value:
        """
        prefix = 'dashboard set-rgw-api-user-id'
        _args = {'prefix': prefix, 'value': value}
        return self._mon_command(_args)
    
    def dashboard_set_ssl_certificate(self, mgr_id: str=None):
        """
        Prefix: ``dashboard set-ssl-certificate``
        
        module=mgr perm=w flags=mgr
        
        :param mgr_id:
        """
        prefix = 'dashboard set-ssl-certificate'
        _args = {'prefix': prefix, 'mgr_id': mgr_id}
        return self._mon_command(_args)
    
    def dashboard_set_ssl_certificate_key(self, mgr_id: str=None):
        """
        Prefix: ``dashboard set-ssl-certificate-key``
        
        module=mgr perm=w flags=mgr
        
        :param mgr_id:
        """
        prefix = 'dashboard set-ssl-certificate-key'
        _args = {'prefix': prefix, 'mgr_id': mgr_id}
        return self._mon_command(_args)
    
    def dashboard_sso_disable(self):
        """
        Prefix: ``dashboard sso disable``
        
        Disable Single Sign-On
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard sso disable'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_sso_enable_saml2(self):
        """
        Prefix: ``dashboard sso enable saml2``
        
        Enable SAML2 Single Sign-On
        
        module=mgr perm=w flags=mgr
        """
        prefix = 'dashboard sso enable saml2'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_sso_setup_saml2(self, ceph_dashboard_base_url: str, idp_metadata: str,
                                  idp_username_attribute: str=None, idp_entity_id: str=None,
                                  sp_x_509_cert: str=None, sp_private_key: str=None):
        """
        Prefix: ``dashboard sso setup saml2``
        
        Setup SAML2 Single Sign-On
        
        module=mgr perm=w flags=mgr
        
        :param ceph_dashboard_base_url:
        :param idp_metadata:
        :param idp_username_attribute:
        :param idp_entity_id:
        :param sp_x_509_cert:
        :param sp_private_key:
        """
        prefix = 'dashboard sso setup saml2'
        _args = {'prefix': prefix, 'ceph_dashboard_base_url': ceph_dashboard_base_url,
                 'idp_metadata': idp_metadata, 'idp_username_attribute':
                 idp_username_attribute, 'idp_entity_id': idp_entity_id,
                 'sp_x_509_cert': sp_x_509_cert, 'sp_private_key':
                 sp_private_key}
        return self._mon_command(_args)
    
    def dashboard_sso_show_saml2(self):
        """
        Prefix: ``dashboard sso show saml2``
        
        Show SAML2 configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard sso show saml2'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def dashboard_sso_status(self):
        """
        Prefix: ``dashboard sso status``
        
        Get Single Sign-On status
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'dashboard sso status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def deepsea_config_set(self, key: str, value: str):
        """
        Prefix: ``deepsea config-set``
        
        Set a configuration value
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        :param value:
        """
        prefix = 'deepsea config-set'
        _args = {'prefix': prefix, 'key': key, 'value': value}
        return self._mon_command(_args)
    
    def deepsea_config_show(self):
        """
        Prefix: ``deepsea config-show``
        
        Show current configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'deepsea config-show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_check_health(self):
        """
        Prefix: ``device check-health``
        
        Check life expectancy of devices
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'device check-health'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_debug_metrics_forced(self):
        """
        Prefix: ``device debug metrics-forced``
        
        Run metrics agent forced
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'device debug metrics-forced'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_debug_smart_forced(self):
        """
        Prefix: ``device debug smart-forced``
        
        Run smart agent forced
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'device debug smart-forced'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_get_health_metrics(self, devid: str, sample: str):
        """
        Prefix: ``device get-health-metrics``
        
        Show stored device metrics for the device
        
        module=mgr perm=r flags=mgr
        
        :param devid:
        :param sample:
        """
        prefix = 'device get-health-metrics'
        _args = {'prefix': prefix, 'devid': devid, 'sample': sample}
        return self._mon_command(_args)
    
    def device_info(self, devid: str):
        """
        Prefix: ``device info``
        
        Show information about a device
        
        module=mgr perm=r flags=mgr
        
        :param devid:
        """
        prefix = 'device info'
        _args = {'prefix': prefix, 'devid': devid}
        return self._mon_command(_args)
    
    def device_ls(self):
        """
        Prefix: ``device ls``
        
        Show devices
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'device ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_ls_by_daemon(self, who: str):
        """
        Prefix: ``device ls-by-daemon``
        
        Show devices associated with a daemon
        
        module=mgr perm=r flags=mgr
        
        :param who:
        """
        prefix = 'device ls-by-daemon'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def device_ls_by_host(self, host: str):
        """
        Prefix: ``device ls-by-host``
        
        Show devices on a host
        
        module=mgr perm=r flags=mgr
        
        :param host:
        """
        prefix = 'device ls-by-host'
        _args = {'prefix': prefix, 'host': host}
        return self._mon_command(_args)
    
    def device_monitoring_off(self):
        """
        Prefix: ``device monitoring off``
        
        Disable device health monitoring
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'device monitoring off'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_monitoring_on(self):
        """
        Prefix: ``device monitoring on``
        
        Enable device health monitoring
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'device monitoring on'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def device_predict_life_expectancy(self, devid: str):
        """
        Prefix: ``device predict-life-expectancy``
        
        Predict life expectancy with local predictor
        
        module=mgr perm=r flags=mgr
        
        :param devid:
        """
        prefix = 'device predict-life-expectancy'
        _args = {'prefix': prefix, 'devid': devid}
        return self._mon_command(_args)
    
    def device_query_daemon_health_metrics(self, who: str):
        """
        Prefix: ``device query-daemon-health-metrics``
        
        Get device health metrics for a given daemon
        
        module=mgr perm=r flags=mgr
        
        :param who:
        """
        prefix = 'device query-daemon-health-metrics'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def device_rm_life_expectancy(self, devid: str):
        """
        Prefix: ``device rm-life-expectancy``
        
        Clear predicted device life expectancy
        
        module=mgr perm=rw flags=mgr
        
        :param devid:
        """
        prefix = 'device rm-life-expectancy'
        _args = {'prefix': prefix, 'devid': devid}
        return self._mon_command(_args)
    
    def device_scrape_daemon_health_metrics(self, who: str):
        """
        Prefix: ``device scrape-daemon-health-metrics``
        
        Scrape and store device health metrics for a given daemon
        
        module=mgr perm=r flags=mgr
        
        :param who:
        """
        prefix = 'device scrape-daemon-health-metrics'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def device_scrape_health_metrics(self, devid: str):
        """
        Prefix: ``device scrape-health-metrics``
        
        Scrape and store health metrics
        
        module=mgr perm=r flags=mgr
        
        :param devid:
        """
        prefix = 'device scrape-health-metrics'
        _args = {'prefix': prefix, 'devid': devid}
        return self._mon_command(_args)
    
    def device_set_cloud_prediction_config(self, server: str, user: str, password: str, certfile: str,
                                           port: str=None):
        """
        Prefix: ``device set-cloud-prediction-config``
        
        Configure Disk Prediction service
        
        module=mgr perm=rw flags=mgr
        
        :param server:
        :param user:
        :param password:
        :param certfile:
        :param port:
        """
        prefix = 'device set-cloud-prediction-config'
        _args = {'prefix': prefix, 'server': server, 'user': user, 'password': password,
                 'certfile': certfile, 'port': port}
        return self._mon_command(_args)
    
    def device_set_life_expectancy(self, devid: str, from_1: str, to: str):
        """
        Prefix: ``device set-life-expectancy``
        
        Set predicted device life expectancy
        
        module=mgr perm=rw flags=mgr
        
        :param devid:
        :param from_1: Real name is ``from``
        :param to:
        """
        prefix = 'device set-life-expectancy'
        _args = {'prefix': prefix, 'devid': devid, 'from': from_1, 'to': to}
        return self._mon_command(_args)
    
    def device_show_prediction_config(self):
        """
        Prefix: ``device show-prediction-config``
        
        Prints diskprediction configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'device show-prediction-config'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def df(self, detail: str=None):
        """
        Prefix: ``df``
        
        show cluster free space stats
        
        module=mon perm=r flags=
        
        :param detail: CephChoices strings=detail
        """
        prefix = 'df'
        _args = {'prefix': prefix, 'detail': detail}
        return self._mon_command(_args)
    
    def diskprediction_cloud_status(self):
        """
        Prefix: ``diskprediction_cloud status``
        
        Check diskprediction_cloud status
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'diskprediction_cloud status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def features(self):
        """
        Prefix: ``features``
        
        report of connected features
        
        module=mon perm=r flags=
        """
        prefix = 'features'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def fs_add_data_pool(self, fs_name: str, pool: str):
        """
        Prefix: ``fs add_data_pool``
        
        add data pool <pool>
        
        module=mds perm=rw flags=
        
        :param fs_name:
        :param pool:
        """
        prefix = 'fs add_data_pool'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'pool': pool}
        return self._mon_command(_args)
    
    def fs_authorize(self, filesystem: str, entity: str, caps: List[str]):
        """
        Prefix: ``fs authorize``
        
        add auth for <entity> to access file system <filesystem> based on
        following directory and permissions pairs
        
        module=auth perm=rwx flags=
        
        :param filesystem:
        :param entity:
        :param caps:
        """
        prefix = 'fs authorize'
        _args = {'prefix': prefix, 'filesystem': filesystem, 'entity': entity, 'caps': caps}
        return self._mon_command(_args)
    
    def fs_dump(self, epoch: int=None):
        """
        Prefix: ``fs dump``
        
        dump all CephFS status, optionally from epoch
        
        module=mds perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'fs dump'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def fs_fail(self, fs_name: str):
        """
        Prefix: ``fs fail``
        
        bring the file system down and all of its ranks
        
        module=fs perm=rw flags=
        
        :param fs_name:
        """
        prefix = 'fs fail'
        _args = {'prefix': prefix, 'fs_name': fs_name}
        return self._mon_command(_args)
    
    def fs_flag_set(self, flag_name: str, val: str, yes_i_really_mean_it:
                    bool=None):
        """
        Prefix: ``fs flag set``
        
        Set a global CephFS flag
        
        module=fs perm=rw flags=
        
        :param flag_name: CephChoices strings=enable_multiple
        :param val:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'fs flag set'
        _args = {'prefix': prefix, 'flag_name': flag_name, 'val': val, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def fs_get(self, fs_name: str):
        """
        Prefix: ``fs get``
        
        get info about one filesystem
        
        module=fs perm=r flags=
        
        :param fs_name:
        """
        prefix = 'fs get'
        _args = {'prefix': prefix, 'fs_name': fs_name}
        return self._mon_command(_args)
    
    def fs_ls(self):
        """
        Prefix: ``fs ls``
        
        list filesystems
        
        module=fs perm=r flags=
        """
        prefix = 'fs ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def fs_new(self, fs_name: str, metadata: str, data: str, force:
               bool=None, allow_dangerous_metadata_overlay: bool=None):
        """
        Prefix: ``fs new``
        
        make new filesystem using named pools <metadata> and <data>
        
        module=fs perm=rw flags=
        
        :param fs_name:
        :param metadata:
        :param data:
        :param force: CephBool
        :param allow_dangerous_metadata_overlay: CephBool
        """
        prefix = 'fs new'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'metadata': metadata, 'data': data,
                 'force': force, 'allow_dangerous_metadata_overlay':
                 allow_dangerous_metadata_overlay}
        return self._mon_command(_args)
    
    def fs_reset(self, fs_name: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``fs reset``
        
        disaster recovery only: reset to a single-MDS map
        
        module=fs perm=rw flags=
        
        :param fs_name:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'fs reset'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def fs_rm(self, fs_name: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``fs rm``
        
        disable the named filesystem
        
        module=fs perm=rw flags=
        
        :param fs_name:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'fs rm'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def fs_rm_data_pool(self, fs_name: str, pool: str):
        """
        Prefix: ``fs rm_data_pool``
        
        remove data pool <pool>
        
        module=mds perm=rw flags=
        
        :param fs_name:
        :param pool:
        """
        prefix = 'fs rm_data_pool'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'pool': pool}
        return self._mon_command(_args)
    
    def fs_set(self, fs_name: str, var: str, val: str,
               yes_i_really_mean_it: bool=None):
        """
        Prefix: ``fs set``
        
        set fs parameter <var> to <val>
        
        module=mds perm=rw flags=
        
        :param fs_name:
        :param var: CephChoices strings=max_mds|max_file_size|allow_new_snaps|
            inline_data|cluster_down|allow_dirfrags|balancer|standby_count_wanted|
            session_timeout|session_autoclose|allow_standby_replay|down|joinable|m
            in_compat_client
        :param val:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'fs set'
        _args = {'prefix': prefix, 'fs_name': fs_name, 'var': var, 'val': val,
                 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    @overload  # Python 3 only
    def fs_set_default(self, fs_name: str):
        """
        Prefix: ``fs set-default``
        
        set the default to the named filesystem
        
        module=fs perm=rw flags=
        
        :param fs_name:
        """
        prefix = 'fs set-default'
        _args = {'prefix': prefix, 'fs_name': fs_name}
        return self._mon_command(_args)
    
    @deprecated
    @overload  # Python 3 only
    def fs_set_default(self, fs_name: str):
        """
        Prefix: ``fs set_default``
        
        set the default to the named filesystem
        
        module=fs perm=rw flags=deprecated
        
        :param fs_name:
        """
        prefix = 'fs set_default'
        _args = {'prefix': prefix, 'fs_name': fs_name}
        return self._mon_command(_args)
    
    def fs_status(self, fs: str=None):
        """
        Prefix: ``fs status``
        
        Show the status of a CephFS filesystem
        
        module=mgr perm=r flags=mgr
        
        :param fs:
        """
        prefix = 'fs status'
        _args = {'prefix': prefix, 'fs': fs}
        return self._mon_command(_args)
    
    def fs_subvolume_create(self, vol_name: str, sub_name: str, size: int=None,
                            group_name: str=None, pool_layout: str=None, mode: str=None):
        """
        Prefix: ``fs subvolume create``
        
        Create a CephFS subvolume in a volume, and optionally, with a specific
        size (in bytes), a specific data pool layout, a specific mode, and in
        a specific subvolume group
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param sub_name:
        :param size: CephInt
        :param group_name:
        :param pool_layout:
        :param mode:
        """
        prefix = 'fs subvolume create'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'sub_name': sub_name, 'size': size,
                 'group_name': group_name, 'pool_layout': pool_layout,
                 'mode': mode}
        return self._mon_command(_args)
    
    def fs_subvolume_getpath(self, vol_name: str, sub_name: str, group_name: str=None):
        """
        Prefix: ``fs subvolume getpath``
        
        Get the mountpath of a CephFS subvolume in a volume, and optionally,
        in a specific subvolume group
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param sub_name:
        :param group_name:
        """
        prefix = 'fs subvolume getpath'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'sub_name': sub_name, 'group_name':
                 group_name}
        return self._mon_command(_args)
    
    def fs_subvolume_rm(self, vol_name: str, sub_name: str, group_name: str=None,
                        force: bool=None):
        """
        Prefix: ``fs subvolume rm``
        
        Delete a CephFS subvolume in a volume, and optionally, in a specific
        subvolume group
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param sub_name:
        :param group_name:
        :param force: CephBool
        """
        prefix = 'fs subvolume rm'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'sub_name': sub_name, 'group_name':
                 group_name, 'force': force}
        return self._mon_command(_args)
    
    def fs_subvolume_snapshot_create(self, vol_name: str, sub_name: str, snap_name: str,
                                     group_name: str=None):
        """
        Prefix: ``fs subvolume snapshot create``
        
        Create a snapshot of a CephFS subvolume in a volume, and optionally,
        in a specific subvolume group
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param sub_name:
        :param snap_name:
        :param group_name:
        """
        prefix = 'fs subvolume snapshot create'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'sub_name': sub_name, 'snap_name':
                 snap_name, 'group_name': group_name}
        return self._mon_command(_args)
    
    def fs_subvolume_snapshot_rm(self, vol_name: str, sub_name: str, snap_name: str,
                                 group_name: str=None, force: bool=None):
        """
        Prefix: ``fs subvolume snapshot rm``
        
        Delete a snapshot of a CephFS subvolume in a volume, and optionally,
        in a specific subvolume group
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param sub_name:
        :param snap_name:
        :param group_name:
        :param force: CephBool
        """
        prefix = 'fs subvolume snapshot rm'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'sub_name': sub_name, 'snap_name':
                 snap_name, 'group_name': group_name, 'force': force}
        return self._mon_command(_args)
    
    def fs_subvolumegroup_create(self, vol_name: str, group_name: str, pool_layout: str=None,
                                 mode: str=None):
        """
        Prefix: ``fs subvolumegroup create``
        
        Create a CephFS subvolume group in a volume, and optionally, with a
        specific data pool layout, and a specific numeric mode
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param group_name:
        :param pool_layout:
        :param mode:
        """
        prefix = 'fs subvolumegroup create'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'group_name': group_name,
                 'pool_layout': pool_layout, 'mode': mode}
        return self._mon_command(_args)
    
    def fs_subvolumegroup_rm(self, vol_name: str, group_name: str, force: bool=None):
        """
        Prefix: ``fs subvolumegroup rm``
        
        Delete a CephFS subvolume group in a volume
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param group_name:
        :param force: CephBool
        """
        prefix = 'fs subvolumegroup rm'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'group_name': group_name, 'force':
                 force}
        return self._mon_command(_args)
    
    def fs_subvolumegroup_snapshot_create(self, vol_name: str, group_name: str, snap_name: str):
        """
        Prefix: ``fs subvolumegroup snapshot create``
        
        Create a snapshot of a CephFS subvolume group in a volume
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param group_name:
        :param snap_name:
        """
        prefix = 'fs subvolumegroup snapshot create'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'group_name': group_name, 'snap_name':
                 snap_name}
        return self._mon_command(_args)
    
    def fs_subvolumegroup_snapshot_rm(self, vol_name: str, group_name: str, snap_name: str, force:
                                      bool=None):
        """
        Prefix: ``fs subvolumegroup snapshot rm``
        
        Delete a snapshot of a CephFS subvolume group in a volume
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        :param group_name:
        :param snap_name:
        :param force: CephBool
        """
        prefix = 'fs subvolumegroup snapshot rm'
        _args = {'prefix': prefix, 'vol_name': vol_name, 'group_name': group_name, 'snap_name':
                 snap_name, 'force': force}
        return self._mon_command(_args)
    
    def fs_volume_create(self, name: str, size: str=None):
        """
        Prefix: ``fs volume create``
        
        Create a CephFS volume
        
        module=mgr perm=rw flags=mgr
        
        :param name:
        :param size:
        """
        prefix = 'fs volume create'
        _args = {'prefix': prefix, 'name': name, 'size': size}
        return self._mon_command(_args)
    
    def fs_volume_ls(self):
        """
        Prefix: ``fs volume ls``
        
        List volumes
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'fs volume ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def fs_volume_rm(self, vol_name: str):
        """
        Prefix: ``fs volume rm``
        
        Delete a CephFS volume
        
        module=mgr perm=rw flags=mgr
        
        :param vol_name:
        """
        prefix = 'fs volume rm'
        _args = {'prefix': prefix, 'vol_name': vol_name}
        return self._mon_command(_args)
    
    def fsid(self):
        """
        Prefix: ``fsid``
        
        show cluster FSID/UUID
        
        module=mon perm=r flags=
        """
        prefix = 'fsid'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def health(self, detail: str=None):
        """
        Prefix: ``health``
        
        show cluster health
        
        module=mon perm=r flags=
        
        :param detail: CephChoices strings=detail
        """
        prefix = 'health'
        _args = {'prefix': prefix, 'detail': detail}
        return self._mon_command(_args)
    
    def heap(self, heapcmd: str):
        """
        Prefix: ``heap``
        
        show heap usage info (available only if compiled with tcmalloc)
        
        module=mon perm=rw flags=no_forward
        
        :param heapcmd: CephChoices
            strings=dump|start_profiler|stop_profiler|release|stats
        """
        prefix = 'heap'
        _args = {'prefix': prefix, 'heapcmd': heapcmd}
        return self._mon_command(_args)
    
    def hello(self, person_name: str=None):
        """
        Prefix: ``hello``
        
        Prints hello world to mgr.x.log
        
        module=mgr perm=r flags=mgr
        
        :param person_name:
        """
        prefix = 'hello'
        _args = {'prefix': prefix, 'person_name': person_name}
        return self._mon_command(_args)
    
    def influx_config_set(self, key: str, value: str):
        """
        Prefix: ``influx config-set``
        
        Set a configuration value
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        :param value:
        """
        prefix = 'influx config-set'
        _args = {'prefix': prefix, 'key': key, 'value': value}
        return self._mon_command(_args)
    
    def influx_config_show(self):
        """
        Prefix: ``influx config-show``
        
        Show current configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'influx config-show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def influx_send(self):
        """
        Prefix: ``influx send``
        
        Force sending data to Influx
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'influx send'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def injectargs(self, injected_args: List[str]):
        """
        Prefix: ``injectargs``
        
        inject config arguments into monitor
        
        module=mon perm=rw flags=no_forward
        
        :param injected_args:
        """
        prefix = 'injectargs'
        _args = {'prefix': prefix, 'injected_args': injected_args}
        return self._mon_command(_args)
    
    def insights(self):
        """
        Prefix: ``insights``
        
        Retrieve insights report
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'insights'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def insights_prune_health(self, hours: str):
        """
        Prefix: ``insights prune-health``
        
        Remove health history older than <hours> hours
        
        module=mgr perm=rw flags=mgr
        
        :param hours:
        """
        prefix = 'insights prune-health'
        _args = {'prefix': prefix, 'hours': hours}
        return self._mon_command(_args)
    
    def iostat(self):
        """
        Prefix: ``iostat``
        
        Get IO rates
        
        module=mgr perm=r flags=poll, mgr
        """
        prefix = 'iostat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def log(self, logtext: List[str]):
        """
        Prefix: ``log``
        
        log supplied text to the monitor log
        
        module=mon perm=rw flags=
        
        :param logtext:
        """
        prefix = 'log'
        _args = {'prefix': prefix, 'logtext': logtext}
        return self._mon_command(_args)
    
    def log_last(self, num: int=None, level: str=None, channel: str=None):
        """
        Prefix: ``log last``
        
        print last few lines of the cluster log
        
        module=mon perm=r flags=
        
        :param num: CephInt range= ``1``
        :param level: CephChoices strings=debug|info|sec|warn|error
        :param channel: CephChoices strings=*|cluster|audit
        """
        prefix = 'log last'
        _args = {'prefix': prefix, 'num': num, 'level': level, 'channel': channel}
        return self._mon_command(_args)
    
    @deprecated
    def mds_add_data_pool(self, pool: str):
        """
        Prefix: ``mds add_data_pool``
        
        add data pool <pool>
        
        module=mds perm=rw flags=obsolete
        
        :param pool:
        """
        prefix = 'mds add_data_pool'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    @deprecated
    def mds_cluster_down(self):
        """
        Prefix: ``mds cluster_down``
        
        take MDS cluster down
        
        module=mds perm=rw flags=obsolete
        """
        prefix = 'mds cluster_down'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def mds_cluster_up(self):
        """
        Prefix: ``mds cluster_up``
        
        bring MDS cluster up
        
        module=mds perm=rw flags=obsolete
        """
        prefix = 'mds cluster_up'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mds_compat_rm_compat(self, feature: int):
        """
        Prefix: ``mds compat rm_compat``
        
        remove compatible feature
        
        module=mds perm=rw flags=
        
        :param feature: CephInt range= ``0``
        """
        prefix = 'mds compat rm_compat'
        _args = {'prefix': prefix, 'feature': feature}
        return self._mon_command(_args)
    
    def mds_compat_rm_incompat(self, feature: int):
        """
        Prefix: ``mds compat rm_incompat``
        
        remove incompatible feature
        
        module=mds perm=rw flags=
        
        :param feature: CephInt range= ``0``
        """
        prefix = 'mds compat rm_incompat'
        _args = {'prefix': prefix, 'feature': feature}
        return self._mon_command(_args)
    
    def mds_compat_show(self):
        """
        Prefix: ``mds compat show``
        
        show mds compatibility settings
        
        module=mds perm=r flags=
        """
        prefix = 'mds compat show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mds_count_metadata(self, property_1: str):
        """
        Prefix: ``mds count-metadata``
        
        count MDSs by metadata field property
        
        module=mds perm=r flags=
        
        :param property_1: Real name is ``property``
        """
        prefix = 'mds count-metadata'
        _args = {'prefix': prefix, 'property': property_1}
        return self._mon_command(_args)
    
    @deprecated
    def mds_deactivate(self, role: str):
        """
        Prefix: ``mds deactivate``
        
        clean up specified MDS rank (use with `set max_mds` to shrink cluster)
        
        module=mds perm=rw flags=obsolete
        
        :param role:
        """
        prefix = 'mds deactivate'
        _args = {'prefix': prefix, 'role': role}
        return self._mon_command(_args)
    
    @deprecated
    def mds_dump(self, epoch: int=None):
        """
        Prefix: ``mds dump``
        
        dump legacy MDS cluster info, optionally from epoch
        
        module=mds perm=r flags=obsolete
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'mds dump'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def mds_fail(self, role_or_gid: str):
        """
        Prefix: ``mds fail``
        
        Mark MDS failed: trigger a failover if a standby is available
        
        module=mds perm=rw flags=
        
        :param role_or_gid:
        """
        prefix = 'mds fail'
        _args = {'prefix': prefix, 'role_or_gid': role_or_gid}
        return self._mon_command(_args)
    
    def mds_freeze(self, role_or_gid: str, val: str):
        """
        Prefix: ``mds freeze``
        
        freeze MDS yes/no
        
        module=mds perm=rw flags=hidden
        
        :param role_or_gid:
        :param val:
        """
        prefix = 'mds freeze'
        _args = {'prefix': prefix, 'role_or_gid': role_or_gid, 'val': val}
        return self._mon_command(_args)
    
    @deprecated
    def mds_getmap(self, epoch: int=None):
        """
        Prefix: ``mds getmap``
        
        get MDS map, optionally from epoch
        
        module=mds perm=r flags=obsolete
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'mds getmap'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def mds_metadata(self, who: str=None):
        """
        Prefix: ``mds metadata``
        
        fetch metadata for mds <role>
        
        module=mds perm=r flags=
        
        :param who:
        """
        prefix = 'mds metadata'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    @deprecated
    def mds_newfs(self, metadata: int, data: int, yes_i_really_mean_it:
                  bool=None):
        """
        Prefix: ``mds newfs``
        
        make new filesystem using pools <metadata> and <data>
        
        module=mds perm=rw flags=obsolete
        
        :param metadata: CephInt range= ``0``
        :param data: CephInt range= ``0``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'mds newfs'
        _args = {'prefix': prefix, 'metadata': metadata, 'data': data, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def mds_ok_to_stop(self, ids: List[str]):
        """
        Prefix: ``mds ok-to-stop``
        
        check whether stopping the specified MDS would reduce immediate
        availability
        
        module=mds perm=r flags=
        
        :param ids:
        """
        prefix = 'mds ok-to-stop'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def mds_remove_data_pool(self, pool: str):
        """
        Prefix: ``mds remove_data_pool``
        
        remove data pool <pool>
        
        module=mds perm=rw flags=obsolete
        
        :param pool:
        """
        prefix = 'mds remove_data_pool'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def mds_repaired(self, role: str):
        """
        Prefix: ``mds repaired``
        
        mark a damaged MDS rank as no longer damaged
        
        module=mds perm=rw flags=
        
        :param role:
        """
        prefix = 'mds repaired'
        _args = {'prefix': prefix, 'role': role}
        return self._mon_command(_args)
    
    def mds_rm(self, gid: int):
        """
        Prefix: ``mds rm``
        
        remove nonactive mds
        
        module=mds perm=rw flags=
        
        :param gid: CephInt range= ``0``
        """
        prefix = 'mds rm'
        _args = {'prefix': prefix, 'gid': gid}
        return self._mon_command(_args)
    
    @deprecated
    def mds_rm_data_pool(self, pool: str):
        """
        Prefix: ``mds rm_data_pool``
        
        remove data pool <pool>
        
        module=mds perm=rw flags=obsolete
        
        :param pool:
        """
        prefix = 'mds rm_data_pool'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def mds_rmfailed(self, role: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``mds rmfailed``
        
        remove failed rank
        
        module=mds perm=rw flags=hidden
        
        :param role:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'mds rmfailed'
        _args = {'prefix': prefix, 'role': role, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    @deprecated
    def mds_set(self, var: str, val: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``mds set``
        
        set mds parameter <var> to <val>
        
        module=mds perm=rw flags=obsolete
        
        :param var: CephChoices strings=max_mds|max_file_size|inline_data|allo
            w_new_snaps|allow_multimds|allow_multimds_snaps|allow_dirfrags
        :param val:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'mds set'
        _args = {'prefix': prefix, 'var': var, 'val': val, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    @deprecated
    def mds_set_max_mds(self, maxmds: int):
        """
        Prefix: ``mds set_max_mds``
        
        set max MDS index
        
        module=mds perm=rw flags=obsolete
        
        :param maxmds: CephInt range= ``0``
        """
        prefix = 'mds set_max_mds'
        _args = {'prefix': prefix, 'maxmds': maxmds}
        return self._mon_command(_args)
    
    def mds_set_state(self, gid: int, state: int):
        """
        Prefix: ``mds set_state``
        
        set mds state of <gid> to <numeric-state>
        
        module=mds perm=rw flags=hidden
        
        :param gid: CephInt range= ``0``
        :param state: CephInt range= ``0..20``
        """
        prefix = 'mds set_state'
        _args = {'prefix': prefix, 'gid': gid, 'state': state}
        return self._mon_command(_args)
    
    def mds_stat(self):
        """
        Prefix: ``mds stat``
        
        show MDS status
        
        module=mds perm=r flags=hidden
        """
        prefix = 'mds stat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def mds_stop(self, role: str):
        """
        Prefix: ``mds stop``
        
        stop mds
        
        module=mds perm=rw flags=obsolete
        
        :param role:
        """
        prefix = 'mds stop'
        _args = {'prefix': prefix, 'role': role}
        return self._mon_command(_args)
    
    @deprecated
    def mds_tell(self, who: str, args: List[str]):
        """
        Prefix: ``mds tell``
        
        send command to particular mds
        
        module=mds perm=rw flags=obsolete
        
        :param who:
        :param args:
        """
        prefix = 'mds tell'
        _args = {'prefix': prefix, 'who': who, 'args': args}
        return self._mon_command(_args)
    
    def mds_versions(self):
        """
        Prefix: ``mds versions``
        
        check running versions of MDSs
        
        module=mds perm=r flags=
        """
        prefix = 'mds versions'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_count_metadata(self, property_1: str):
        """
        Prefix: ``mgr count-metadata``
        
        count ceph-mgr daemons by metadata field property
        
        module=mgr perm=r flags=
        
        :param property_1: Real name is ``property``
        """
        prefix = 'mgr count-metadata'
        _args = {'prefix': prefix, 'property': property_1}
        return self._mon_command(_args)
    
    def mgr_dump(self, epoch: int=None):
        """
        Prefix: ``mgr dump``
        
        dump the latest MgrMap
        
        module=mgr perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'mgr dump'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def mgr_fail(self, who: str):
        """
        Prefix: ``mgr fail``
        
        treat the named manager daemon as failed
        
        module=mgr perm=rw flags=
        
        :param who:
        """
        prefix = 'mgr fail'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def mgr_metadata(self, who: str=None):
        """
        Prefix: ``mgr metadata``
        
        dump metadata for all daemons or a specific daemon
        
        module=mgr perm=r flags=
        
        :param who:
        """
        prefix = 'mgr metadata'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def mgr_module_disable(self, module: str):
        """
        Prefix: ``mgr module disable``
        
        disable mgr module
        
        module=mgr perm=rw flags=
        
        :param module:
        """
        prefix = 'mgr module disable'
        _args = {'prefix': prefix, 'module': module}
        return self._mon_command(_args)
    
    def mgr_module_enable(self, module: str, force: str=None):
        """
        Prefix: ``mgr module enable``
        
        enable mgr module
        
        module=mgr perm=rw flags=
        
        :param module:
        :param force: CephChoices strings=--force
        """
        prefix = 'mgr module enable'
        _args = {'prefix': prefix, 'module': module, 'force': force}
        return self._mon_command(_args)
    
    def mgr_module_ls(self):
        """
        Prefix: ``mgr module ls``
        
        list active mgr modules
        
        module=mgr perm=r flags=
        """
        prefix = 'mgr module ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_self_test_background_start(self, workload: str):
        """
        Prefix: ``mgr self-test background start``
        
        Activate a background workload (one of command_spam, throw_exception)
        
        module=mgr perm=rw flags=mgr
        
        :param workload:
        """
        prefix = 'mgr self-test background start'
        _args = {'prefix': prefix, 'workload': workload}
        return self._mon_command(_args)
    
    def mgr_self_test_background_stop(self):
        """
        Prefix: ``mgr self-test background stop``
        
        Stop background workload if any is running
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'mgr self-test background stop'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_self_test_cluster_log(self, channel: str, priority: str, message: str):
        """
        Prefix: ``mgr self-test cluster-log``
        
        Create an audit log record.
        
        module=mgr perm=rw flags=mgr
        
        :param channel:
        :param priority:
        :param message:
        """
        prefix = 'mgr self-test cluster-log'
        _args = {'prefix': prefix, 'channel': channel, 'priority': priority, 'message': message}
        return self._mon_command(_args)
    
    def mgr_self_test_config_get(self, key: str):
        """
        Prefix: ``mgr self-test config get``
        
        Peek at a configuration value
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        """
        prefix = 'mgr self-test config get'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def mgr_self_test_config_get_localized(self, key: str):
        """
        Prefix: ``mgr self-test config get_localized``
        
        Peek at a configuration value (localized variant)
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        """
        prefix = 'mgr self-test config get_localized'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def mgr_self_test_health_clear(self, checks: List[str]):
        """
        Prefix: ``mgr self-test health clear``
        
        Clear health checks by name. If no names provided, clear all.
        
        module=mgr perm=rw flags=mgr
        
        :param checks:
        """
        prefix = 'mgr self-test health clear'
        _args = {'prefix': prefix, 'checks': checks}
        return self._mon_command(_args)
    
    def mgr_self_test_health_set(self, checks: str):
        """
        Prefix: ``mgr self-test health set``
        
        Set a health check from a JSON-formatted description.
        
        module=mgr perm=rw flags=mgr
        
        :param checks:
        """
        prefix = 'mgr self-test health set'
        _args = {'prefix': prefix, 'checks': checks}
        return self._mon_command(_args)
    
    def mgr_self_test_insights_set_now_offset(self, hours: str):
        """
        Prefix: ``mgr self-test insights_set_now_offset``
        
        Set the now time for the insights module.
        
        module=mgr perm=rw flags=mgr
        
        :param hours:
        """
        prefix = 'mgr self-test insights_set_now_offset'
        _args = {'prefix': prefix, 'hours': hours}
        return self._mon_command(_args)
    
    def mgr_self_test_module(self, module: str):
        """
        Prefix: ``mgr self-test module``
        
        Run another module's self_test() method
        
        module=mgr perm=rw flags=mgr
        
        :param module:
        """
        prefix = 'mgr self-test module'
        _args = {'prefix': prefix, 'module': module}
        return self._mon_command(_args)
    
    def mgr_self_test_remote(self):
        """
        Prefix: ``mgr self-test remote``
        
        Test inter-module calls
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'mgr self-test remote'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_self_test_run(self):
        """
        Prefix: ``mgr self-test run``
        
        Run mgr python interface tests
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'mgr self-test run'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_services(self):
        """
        Prefix: ``mgr services``
        
        list service endpoints provided by mgr modules
        
        module=mgr perm=r flags=
        """
        prefix = 'mgr services'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mgr_versions(self):
        """
        Prefix: ``mgr versions``
        
        check running versions of ceph-mgr daemons
        
        module=mgr perm=r flags=
        """
        prefix = 'mgr versions'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_add(self, name: str, addr: str):
        """
        Prefix: ``mon add``
        
        add new monitor named <name> at <addr>
        
        module=mon perm=rw flags=
        
        :param name:
        :param addr: CephIPAddr
        """
        prefix = 'mon add'
        _args = {'prefix': prefix, 'name': name, 'addr': addr}
        return self._mon_command(_args)
    
    def mon_compact(self):
        """
        Prefix: ``mon compact``
        
        cause compaction of monitor's leveldb/rocksdb storage
        
        module=mon perm=rw flags=no_forward
        """
        prefix = 'mon compact'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_count_metadata(self, property_1: str):
        """
        Prefix: ``mon count-metadata``
        
        count mons by metadata field property
        
        module=mon perm=r flags=
        
        :param property_1: Real name is ``property``
        """
        prefix = 'mon count-metadata'
        _args = {'prefix': prefix, 'property': property_1}
        return self._mon_command(_args)
    
    def mon_dump(self, epoch: int=None):
        """
        Prefix: ``mon dump``
        
        dump formatted monmap (optionally from epoch)
        
        module=mon perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'mon dump'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def mon_enable_msgr2(self):
        """
        Prefix: ``mon enable-msgr2``
        
        enable the msgr2 protocol on port 3300
        
        module=mon perm=rw flags=
        """
        prefix = 'mon enable-msgr2'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_feature_ls(self, with_value: str=None):
        """
        Prefix: ``mon feature ls``
        
        list available mon map features to be set/unset
        
        module=mon perm=r flags=
        
        :param with_value: CephChoices strings=--with-value
        """
        prefix = 'mon feature ls'
        _args = {'prefix': prefix, 'with_value': with_value}
        return self._mon_command(_args)
    
    def mon_feature_set(self, feature_name: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``mon feature set``
        
        set provided feature on mon map
        
        module=mon perm=rw flags=
        
        :param feature_name:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'mon feature set'
        _args = {'prefix': prefix, 'feature_name': feature_name, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def mon_getmap(self, epoch: int=None):
        """
        Prefix: ``mon getmap``
        
        get monmap
        
        module=mon perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'mon getmap'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def mon_metadata(self, id_1: str=None):
        """
        Prefix: ``mon metadata``
        
        fetch metadata for mon <id>
        
        module=mon perm=r flags=
        
        :param id_1: Real name is ``id``
        """
        prefix = 'mon metadata'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def mon_ok_to_add_offline(self):
        """
        Prefix: ``mon ok-to-add-offline``
        
        check whether adding a mon and not starting it would break quorum
        
        module=mon perm=r flags=
        """
        prefix = 'mon ok-to-add-offline'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_ok_to_rm(self, id_1: str):
        """
        Prefix: ``mon ok-to-rm``
        
        check whether removing the specified mon would break quorum
        
        module=mon perm=r flags=
        
        :param id_1: Real name is ``id``
        """
        prefix = 'mon ok-to-rm'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def mon_ok_to_stop(self, ids: List[str]):
        """
        Prefix: ``mon ok-to-stop``
        
        check whether mon(s) can be safely stopped without reducing immediate
        availability
        
        module=mon perm=r flags=
        
        :param ids:
        """
        prefix = 'mon ok-to-stop'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def mon_remove(self, name: str):
        """
        Prefix: ``mon remove``
        
        remove monitor named <name>
        
        module=mon perm=rw flags=deprecated
        
        :param name:
        """
        prefix = 'mon remove'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    def mon_rm(self, name: str):
        """
        Prefix: ``mon rm``
        
        remove monitor named <name>
        
        module=mon perm=rw flags=
        
        :param name:
        """
        prefix = 'mon rm'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    def mon_scrub(self):
        """
        Prefix: ``mon scrub``
        
        scrub the monitor stores
        
        module=mon perm=rw flags=
        """
        prefix = 'mon scrub'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_set_addrs(self, name: str, addrs: str):
        """
        Prefix: ``mon set-addrs``
        
        set the addrs (IPs and ports) a specific monitor binds to
        
        module=mon perm=rw flags=
        
        :param name:
        :param addrs:
        """
        prefix = 'mon set-addrs'
        _args = {'prefix': prefix, 'name': name, 'addrs': addrs}
        return self._mon_command(_args)
    
    def mon_set_rank(self, name: str, rank: int):
        """
        Prefix: ``mon set-rank``
        
        set the rank for the specified mon
        
        module=mon perm=rw flags=
        
        :param name:
        :param rank: CephInt
        """
        prefix = 'mon set-rank'
        _args = {'prefix': prefix, 'name': name, 'rank': rank}
        return self._mon_command(_args)
    
    def mon_set_weight(self, name: str, weight: int):
        """
        Prefix: ``mon set-weight``
        
        set the weight for the specified mon
        
        module=mon perm=rw flags=
        
        :param name:
        :param weight: CephInt range= ``0..65535``
        """
        prefix = 'mon set-weight'
        _args = {'prefix': prefix, 'name': name, 'weight': weight}
        return self._mon_command(_args)
    
    def mon_stat(self):
        """
        Prefix: ``mon stat``
        
        summarize monitor status
        
        module=mon perm=r flags=
        """
        prefix = 'mon stat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_sync_force(self, yes_i_really_mean_it: bool=None,
                       i_know_what_i_am_doing: bool=None):
        """
        Prefix: ``mon sync force``
        
        force sync of and clear monitor store
        
        module=mon perm=rw flags=no_forward
        
        :param yes_i_really_mean_it: CephBool
        :param i_know_what_i_am_doing: CephBool
        """
        prefix = 'mon sync force'
        _args = {'prefix': prefix, 'yes_i_really_mean_it': yes_i_really_mean_it,
                 'i_know_what_i_am_doing': i_know_what_i_am_doing}
        return self._mon_command(_args)
    
    def mon_versions(self):
        """
        Prefix: ``mon versions``
        
        check running versions of monitors
        
        module=mon perm=r flags=
        """
        prefix = 'mon versions'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def mon_status(self):
        """
        Prefix: ``mon_status``
        
        report status of monitors
        
        module=mon perm=r flags=no_forward
        """
        prefix = 'mon_status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def node_ls(self, type_1: str=None):
        """
        Prefix: ``node ls``
        
        list all nodes in cluster [type]
        
        module=mon perm=r flags=
        
        :param type_1: CephChoices strings=all|osd|mon|mds|mgr Real name is
            ``type``
        """
        prefix = 'node ls'
        _args = {'prefix': prefix, 'type': type_1}
        return self._mon_command(_args)
    
    def orchestrator_device_ls(self, host: List[str]=None, format: str=None, refresh:
                               bool=None):
        """
        Prefix: ``orchestrator device ls``
        
        List devices on a node
        
        module=mgr perm=r flags=mgr
        
        :param host:
        :param format: CephChoices strings=json|plain
        :param refresh: CephBool
        """
        prefix = 'orchestrator device ls'
        _args = {'prefix': prefix, 'host': host, 'format': format, 'refresh': refresh}
        return self._mon_command(_args)
    
    def orchestrator_host_add(self, host: str):
        """
        Prefix: ``orchestrator host add``
        
        Add a host
        
        module=mgr perm=rw flags=mgr
        
        :param host:
        """
        prefix = 'orchestrator host add'
        _args = {'prefix': prefix, 'host': host}
        return self._mon_command(_args)
    
    def orchestrator_host_ls(self):
        """
        Prefix: ``orchestrator host ls``
        
        List hosts
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'orchestrator host ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def orchestrator_host_rm(self, host: str):
        """
        Prefix: ``orchestrator host rm``
        
        Remove a host
        
        module=mgr perm=rw flags=mgr
        
        :param host:
        """
        prefix = 'orchestrator host rm'
        _args = {'prefix': prefix, 'host': host}
        return self._mon_command(_args)
    
    def orchestrator_mds_add(self, svc_arg: str):
        """
        Prefix: ``orchestrator mds add``
        
        Create an MDS service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_arg:
        """
        prefix = 'orchestrator mds add'
        _args = {'prefix': prefix, 'svc_arg': svc_arg}
        return self._mon_command(_args)
    
    def orchestrator_mds_rm(self, svc_id: str):
        """
        Prefix: ``orchestrator mds rm``
        
        Remove an MDS service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_id:
        """
        prefix = 'orchestrator mds rm'
        _args = {'prefix': prefix, 'svc_id': svc_id}
        return self._mon_command(_args)
    
    def orchestrator_mgr_update(self, num: int, hosts: List[str]=None):
        """
        Prefix: ``orchestrator mgr update``
        
        Update the number of manager instances
        
        module=mgr perm=rw flags=mgr
        
        :param num: CephInt
        :param hosts:
        """
        prefix = 'orchestrator mgr update'
        _args = {'prefix': prefix, 'num': num, 'hosts': hosts}
        return self._mon_command(_args)
    
    def orchestrator_mon_update(self, num: int, hosts: List[str]=None):
        """
        Prefix: ``orchestrator mon update``
        
        Update the number of monitor instances
        
        module=mgr perm=rw flags=mgr
        
        :param num: CephInt
        :param hosts:
        """
        prefix = 'orchestrator mon update'
        _args = {'prefix': prefix, 'num': num, 'hosts': hosts}
        return self._mon_command(_args)
    
    def orchestrator_nfs_add(self, svc_arg: str, pool: str, namespace: str=None):
        """
        Prefix: ``orchestrator nfs add``
        
        Create an NFS service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_arg:
        :param pool:
        :param namespace:
        """
        prefix = 'orchestrator nfs add'
        _args = {'prefix': prefix, 'svc_arg': svc_arg, 'pool': pool, 'namespace': namespace}
        return self._mon_command(_args)
    
    def orchestrator_nfs_rm(self, svc_id: str):
        """
        Prefix: ``orchestrator nfs rm``
        
        Remove an NFS service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_id:
        """
        prefix = 'orchestrator nfs rm'
        _args = {'prefix': prefix, 'svc_id': svc_id}
        return self._mon_command(_args)
    
    def orchestrator_nfs_update(self, svc_id: str, num: int):
        """
        Prefix: ``orchestrator nfs update``
        
        Scale an NFS service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_id:
        :param num: CephInt
        """
        prefix = 'orchestrator nfs update'
        _args = {'prefix': prefix, 'svc_id': svc_id, 'num': num}
        return self._mon_command(_args)
    
    def orchestrator_osd_create(self, svc_arg: str=None):
        """
        Prefix: ``orchestrator osd create``
        
        Create an OSD service. Either --svc_arg=host:drives or -i
        <drive_group>
        
        module=mgr perm=rw flags=mgr
        
        :param svc_arg:
        """
        prefix = 'orchestrator osd create'
        _args = {'prefix': prefix, 'svc_arg': svc_arg}
        return self._mon_command(_args)
    
    def orchestrator_osd_rm(self, svc_id: List[str]):
        """
        Prefix: ``orchestrator osd rm``
        
        Remove OSD services
        
        module=mgr perm=rw flags=mgr
        
        :param svc_id:
        """
        prefix = 'orchestrator osd rm'
        _args = {'prefix': prefix, 'svc_id': svc_id}
        return self._mon_command(_args)
    
    def orchestrator_rgw_add(self, svc_arg: str):
        """
        Prefix: ``orchestrator rgw add``
        
        Create an RGW service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_arg:
        """
        prefix = 'orchestrator rgw add'
        _args = {'prefix': prefix, 'svc_arg': svc_arg}
        return self._mon_command(_args)
    
    def orchestrator_rgw_rm(self, svc_id: str):
        """
        Prefix: ``orchestrator rgw rm``
        
        Remove an RGW service
        
        module=mgr perm=rw flags=mgr
        
        :param svc_id:
        """
        prefix = 'orchestrator rgw rm'
        _args = {'prefix': prefix, 'svc_id': svc_id}
        return self._mon_command(_args)
    
    def orchestrator_service(self, action: str, svc_type: str, svc_name: str):
        """
        Prefix: ``orchestrator service``
        
        Start, stop or reload an entire service (i.e. all daemons)
        
        module=mgr perm=rw flags=mgr
        
        :param action: CephChoices strings=start|stop|reload
        :param svc_type:
        :param svc_name:
        """
        prefix = 'orchestrator service'
        _args = {'prefix': prefix, 'action': action, 'svc_type': svc_type, 'svc_name': svc_name}
        return self._mon_command(_args)
    
    def orchestrator_service_ls(self, host: str=None, svc_type: str=None, svc_id: str=None,
                                format: str=None):
        """
        Prefix: ``orchestrator service ls``
        
        List services known to orchestrator
        
        module=mgr perm=r flags=mgr
        
        :param host:
        :param svc_type: CephChoices strings=mon|mgr|osd|mds|nfs|rgw|rbd-
            mirror
        :param svc_id:
        :param format: CephChoices strings=json|plain
        """
        prefix = 'orchestrator service ls'
        _args = {'prefix': prefix, 'host': host, 'svc_type': svc_type, 'svc_id': svc_id,
                 'format': format}
        return self._mon_command(_args)
    
    def orchestrator_service_instance(self, action: str, svc_type: str, svc_id: str):
        """
        Prefix: ``orchestrator service-instance``
        
        Start, stop or reload a specific service instance
        
        module=mgr perm=rw flags=mgr
        
        :param action: CephChoices strings=start|stop|reload
        :param svc_type:
        :param svc_id:
        """
        prefix = 'orchestrator service-instance'
        _args = {'prefix': prefix, 'action': action, 'svc_type': svc_type, 'svc_id': svc_id}
        return self._mon_command(_args)
    
    def orchestrator_set_backend(self, module_name: str):
        """
        Prefix: ``orchestrator set backend``
        
        Select orchestrator module backend
        
        module=mgr perm=rw flags=mgr
        
        :param module_name:
        """
        prefix = 'orchestrator set backend'
        _args = {'prefix': prefix, 'module_name': module_name}
        return self._mon_command(_args)
    
    def orchestrator_status(self):
        """
        Prefix: ``orchestrator status``
        
        Report configured backend and its status
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'orchestrator status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def osd_add_nodown(self, ids: List[str]):
        """
        Prefix: ``osd add-nodown``
        
        mark osd(s) <id> [<id>...] as nodown, or use <all|any> to mark all
        osds as nodown
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd add-nodown'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_add_noin(self, ids: List[str]):
        """
        Prefix: ``osd add-noin``
        
        mark osd(s) <id> [<id>...] as noin, or use <all|any> to mark all osds
        as noin
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd add-noin'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_add_noout(self, ids: List[str]):
        """
        Prefix: ``osd add-noout``
        
        mark osd(s) <id> [<id>...] as noout, or use <all|any> to mark all osds
        as noout
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd add-noout'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_add_noup(self, ids: List[str]):
        """
        Prefix: ``osd add-noup``
        
        mark osd(s) <id> [<id>...] as noup, or use <all|any> to mark all osds
        as noup
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd add-noup'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_blacklist(self, blacklistop: str, addr: str, expire: float=None):
        """
        Prefix: ``osd blacklist``
        
        add (optionally until <expire> seconds from now) or remove <addr> from
        blacklist
        
        module=osd perm=rw flags=
        
        :param blacklistop: CephChoices strings=add|rm
        :param addr: CephEntityAddr
        :param expire: CephFloat range= ``0.0``
        """
        prefix = 'osd blacklist'
        _args = {'prefix': prefix, 'blacklistop': blacklistop, 'addr': addr, 'expire': expire}
        return self._mon_command(_args)
    
    def osd_blacklist_clear(self):
        """
        Prefix: ``osd blacklist clear``
        
        clear all blacklisted clients
        
        module=osd perm=rw flags=
        """
        prefix = 'osd blacklist clear'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_blacklist_ls(self):
        """
        Prefix: ``osd blacklist ls``
        
        show blacklisted clients
        
        module=osd perm=r flags=
        """
        prefix = 'osd blacklist ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_blocked_by(self):
        """
        Prefix: ``osd blocked-by``
        
        print histogram of which OSDs are blocking their peers
        
        module=osd perm=r flags=mgr
        """
        prefix = 'osd blocked-by'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_count_metadata(self, property_1: str):
        """
        Prefix: ``osd count-metadata``
        
        count OSDs by metadata field property
        
        module=osd perm=r flags=
        
        :param property_1: Real name is ``property``
        """
        prefix = 'osd count-metadata'
        _args = {'prefix': prefix, 'property': property_1}
        return self._mon_command(_args)
    
    @deprecated
    def osd_create(self, uuid: str=None, id_1: str=None):
        """
        Prefix: ``osd create``
        
        create new osd (with optional UUID and ID)
        
        module=osd perm=rw flags=deprecated
        
        :param uuid: CephUUID
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd create'
        _args = {'prefix': prefix, 'uuid': uuid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_crush_add(self, id_1: str, weight: float, args: List[str]):
        """
        Prefix: ``osd crush add``
        
        add or update crushmap position and weight for <name> with <weight>
        and location <args>
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param weight: CephFloat range= ``0.0``
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush add'
        _args = {'prefix': prefix, 'id': id_1, 'weight': weight, 'args': args}
        return self._mon_command(_args)
    
    def osd_crush_add_bucket(self, name: str, type_1: str, args: List[str]=None):
        """
        Prefix: ``osd crush add-bucket``
        
        add no-parent (probably root) crush bucket <name> of type <type> to
        location <args>
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param type_1: Real name is ``type``
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush add-bucket'
        _args = {'prefix': prefix, 'name': name, 'type': type_1, 'args': args}
        return self._mon_command(_args)
    
    def osd_crush_class_create(self, class_1: str):
        """
        Prefix: ``osd crush class create``
        
        create crush device class <class>
        
        module=osd perm=rw flags=
        
        :param class_1: goodchars= ``[A-Za-z0-9-_]`` Real name is ``class``
        """
        prefix = 'osd crush class create'
        _args = {'prefix': prefix, 'class': class_1}
        return self._mon_command(_args)
    
    def osd_crush_class_ls(self):
        """
        Prefix: ``osd crush class ls``
        
        list all crush device classes
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush class ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_class_ls_osd(self, class_1: str):
        """
        Prefix: ``osd crush class ls-osd``
        
        list all osds belonging to the specific <class>
        
        module=osd perm=r flags=
        
        :param class_1: goodchars= ``[A-Za-z0-9-_]`` Real name is ``class``
        """
        prefix = 'osd crush class ls-osd'
        _args = {'prefix': prefix, 'class': class_1}
        return self._mon_command(_args)
    
    def osd_crush_class_rename(self, srcname: str, dstname: str):
        """
        Prefix: ``osd crush class rename``
        
        rename crush device class <srcname> to <dstname>
        
        module=osd perm=rw flags=
        
        :param srcname: goodchars= ``[A-Za-z0-9-_]``
        :param dstname: goodchars= ``[A-Za-z0-9-_]``
        """
        prefix = 'osd crush class rename'
        _args = {'prefix': prefix, 'srcname': srcname, 'dstname': dstname}
        return self._mon_command(_args)
    
    def osd_crush_class_rm(self, class_1: str):
        """
        Prefix: ``osd crush class rm``
        
        remove crush device class <class>
        
        module=osd perm=rw flags=
        
        :param class_1: goodchars= ``[A-Za-z0-9-_]`` Real name is ``class``
        """
        prefix = 'osd crush class rm'
        _args = {'prefix': prefix, 'class': class_1}
        return self._mon_command(_args)
    
    def osd_crush_create_or_move(self, id_1: str, weight: float, args: List[str]):
        """
        Prefix: ``osd crush create-or-move``
        
        create entry or move existing entry for <name> <weight> at/to location
        <args>
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param weight: CephFloat range= ``0.0``
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush create-or-move'
        _args = {'prefix': prefix, 'id': id_1, 'weight': weight, 'args': args}
        return self._mon_command(_args)
    
    def osd_crush_dump(self):
        """
        Prefix: ``osd crush dump``
        
        dump crush map
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush dump'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_get_device_class(self, ids: List[str]):
        """
        Prefix: ``osd crush get-device-class``
        
        get classes of specified osd(s) <id> [<id>...]
        
        module=osd perm=r flags=
        
        :param ids:
        """
        prefix = 'osd crush get-device-class'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_crush_get_tunable(self, tunable: str):
        """
        Prefix: ``osd crush get-tunable``
        
        get crush tunable <tunable>
        
        module=osd perm=r flags=
        
        :param tunable: CephChoices strings=straw_calc_version
        """
        prefix = 'osd crush get-tunable'
        _args = {'prefix': prefix, 'tunable': tunable}
        return self._mon_command(_args)
    
    def osd_crush_link(self, name: str, args: List[str]):
        """
        Prefix: ``osd crush link``
        
        link existing entry for <name> under location <args>
        
        module=osd perm=rw flags=
        
        :param name:
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush link'
        _args = {'prefix': prefix, 'name': name, 'args': args}
        return self._mon_command(_args)
    
    def osd_crush_ls(self, node: str):
        """
        Prefix: ``osd crush ls``
        
        list items beneath a node in the CRUSH tree
        
        module=osd perm=r flags=
        
        :param node: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush ls'
        _args = {'prefix': prefix, 'node': node}
        return self._mon_command(_args)
    
    def osd_crush_move(self, name: str, args: List[str]):
        """
        Prefix: ``osd crush move``
        
        move existing entry for <name> to location <args>
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush move'
        _args = {'prefix': prefix, 'name': name, 'args': args}
        return self._mon_command(_args)
    
    @deprecated
    def osd_crush_remove(self, name: str, ancestor: str=None):
        """
        Prefix: ``osd crush remove``
        
        remove <name> from crush map (everywhere, or just at <ancestor>)
        
        module=osd perm=rw flags=deprecated
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param ancestor: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush remove'
        _args = {'prefix': prefix, 'name': name, 'ancestor': ancestor}
        return self._mon_command(_args)
    
    def osd_crush_rename_bucket(self, srcname: str, dstname: str):
        """
        Prefix: ``osd crush rename-bucket``
        
        rename bucket <srcname> to <dstname>
        
        module=osd perm=rw flags=
        
        :param srcname: goodchars= ``[A-Za-z0-9-_.]``
        :param dstname: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush rename-bucket'
        _args = {'prefix': prefix, 'srcname': srcname, 'dstname': dstname}
        return self._mon_command(_args)
    
    def osd_crush_reweight(self, name: str, weight: float):
        """
        Prefix: ``osd crush reweight``
        
        change <name>'s weight to <weight> in crush map
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param weight: CephFloat range= ``0.0``
        """
        prefix = 'osd crush reweight'
        _args = {'prefix': prefix, 'name': name, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_crush_reweight_all(self):
        """
        Prefix: ``osd crush reweight-all``
        
        recalculate the weights for the tree to ensure they sum correctly
        
        module=osd perm=rw flags=
        """
        prefix = 'osd crush reweight-all'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_reweight_subtree(self, name: str, weight: float):
        """
        Prefix: ``osd crush reweight-subtree``
        
        change all leaf items beneath <name> to <weight> in crush map
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param weight: CephFloat range= ``0.0``
        """
        prefix = 'osd crush reweight-subtree'
        _args = {'prefix': prefix, 'name': name, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_crush_rm(self, name: str, ancestor: str=None):
        """
        Prefix: ``osd crush rm``
        
        remove <name> from crush map (everywhere, or just at <ancestor>)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param ancestor: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush rm'
        _args = {'prefix': prefix, 'name': name, 'ancestor': ancestor}
        return self._mon_command(_args)
    
    def osd_crush_rm_device_class(self, ids: List[str]):
        """
        Prefix: ``osd crush rm-device-class``
        
        remove class of the osd(s) <id> [<id>...],or use <all|any> to remove
        all.
        
        module=osd perm=rw flags=
        
        :param ids:
        """
        prefix = 'osd crush rm-device-class'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_crush_rule_create_erasure(self, name: str, profile: str=None):
        """
        Prefix: ``osd crush rule create-erasure``
        
        create crush rule <name> for erasure coded pool created with <profile>
        (default default)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param profile: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush rule create-erasure'
        _args = {'prefix': prefix, 'name': name, 'profile': profile}
        return self._mon_command(_args)
    
    def osd_crush_rule_create_replicated(self, name: str, root: str, type_1: str, class_1: str=None):
        """
        Prefix: ``osd crush rule create-replicated``
        
        create crush rule <name> for replicated pool to start from <root>,
        replicate across buckets of type <type>, use devices of type <class>
        (ssd or hdd)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param root: goodchars= ``[A-Za-z0-9-_.]``
        :param type_1: goodchars= ``[A-Za-z0-9-_.]`` Real name is ``type``
        :param class_1: goodchars= ``[A-Za-z0-9-_.]`` Real name is ``class``
        """
        prefix = 'osd crush rule create-replicated'
        _args = {'prefix': prefix, 'name': name, 'root': root, 'type': type_1, 'class': class_1}
        return self._mon_command(_args)
    
    def osd_crush_rule_create_simple(self, name: str, root: str, type_1: str, mode: str=None):
        """
        Prefix: ``osd crush rule create-simple``
        
        create crush rule <name> to start from <root>, replicate across
        buckets of type <type>, using a choose mode of <firstn|indep> (default
        firstn; indep best for erasure pools)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param root: goodchars= ``[A-Za-z0-9-_.]``
        :param type_1: goodchars= ``[A-Za-z0-9-_.]`` Real name is ``type``
        :param mode: CephChoices strings=firstn|indep
        """
        prefix = 'osd crush rule create-simple'
        _args = {'prefix': prefix, 'name': name, 'root': root, 'type': type_1, 'mode': mode}
        return self._mon_command(_args)
    
    def osd_crush_rule_dump(self, name: str=None):
        """
        Prefix: ``osd crush rule dump``
        
        dump crush rule <name> (default all)
        
        module=osd perm=r flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush rule dump'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    @deprecated
    def osd_crush_rule_list(self):
        """
        Prefix: ``osd crush rule list``
        
        list crush rules
        
        module=osd perm=r flags=deprecated
        """
        prefix = 'osd crush rule list'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_rule_ls(self):
        """
        Prefix: ``osd crush rule ls``
        
        list crush rules
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush rule ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_rule_ls_by_class(self, class_1: str):
        """
        Prefix: ``osd crush rule ls-by-class``
        
        list all crush rules that reference the same <class>
        
        module=osd perm=r flags=
        
        :param class_1: goodchars= ``[A-Za-z0-9-_.]`` Real name is ``class``
        """
        prefix = 'osd crush rule ls-by-class'
        _args = {'prefix': prefix, 'class': class_1}
        return self._mon_command(_args)
    
    def osd_crush_rule_rename(self, srcname: str, dstname: str):
        """
        Prefix: ``osd crush rule rename``
        
        rename crush rule <srcname> to <dstname>
        
        module=osd perm=rw flags=
        
        :param srcname: goodchars= ``[A-Za-z0-9-_.]``
        :param dstname: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush rule rename'
        _args = {'prefix': prefix, 'srcname': srcname, 'dstname': dstname}
        return self._mon_command(_args)
    
    def osd_crush_rule_rm(self, name: str):
        """
        Prefix: ``osd crush rule rm``
        
        remove crush rule <name>
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush rule rm'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    @overload  # Python 3 only
    def osd_crush_set(self, prior_version: int=None):
        """
        Prefix: ``osd crush set``
        
        set crush map from input file
        
        module=osd perm=rw flags=
        
        :param prior_version: CephInt
        """
        prefix = 'osd crush set'
        _args = {'prefix': prefix, 'prior_version': prior_version}
        return self._mon_command(_args)
    
    @overload  # Python 3 only
    def osd_crush_set(self, id_1: str, weight: float, args: List[str]):
        """
        Prefix: ``osd crush set``
        
        update crushmap position and weight for <name> to <weight> with
        location <args>
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param weight: CephFloat range= ``0.0``
        :param args: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd crush set'
        _args = {'prefix': prefix, 'id': id_1, 'weight': weight, 'args': args}
        return self._mon_command(_args)
    
    def osd_crush_set_all_straw_buckets_to_straw2(self):
        """
        Prefix: ``osd crush set-all-straw-buckets-to-straw2``
        
        convert all CRUSH current straw buckets to use the straw2 algorithm
        
        module=osd perm=rw flags=
        """
        prefix = 'osd crush set-all-straw-buckets-to-straw2'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_set_device_class(self, class_1: str, ids: List[str]):
        """
        Prefix: ``osd crush set-device-class``
        
        set the <class> of the osd(s) <id> [<id>...],or use <all|any> to set
        all.
        
        module=osd perm=rw flags=
        
        :param class_1: Real name is ``class``
        :param ids:
        """
        prefix = 'osd crush set-device-class'
        _args = {'prefix': prefix, 'class': class_1, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_crush_set_tunable(self, tunable: str, value: int):
        """
        Prefix: ``osd crush set-tunable``
        
        set crush tunable <tunable> to <value>
        
        module=osd perm=rw flags=
        
        :param tunable: CephChoices strings=straw_calc_version
        :param value: CephInt
        """
        prefix = 'osd crush set-tunable'
        _args = {'prefix': prefix, 'tunable': tunable, 'value': value}
        return self._mon_command(_args)
    
    def osd_crush_show_tunables(self):
        """
        Prefix: ``osd crush show-tunables``
        
        show current crush tunables
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush show-tunables'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_swap_bucket(self, source: str, dest: str, yes_i_really_mean_it:
                              bool=None):
        """
        Prefix: ``osd crush swap-bucket``
        
        swap existing bucket contents from (orphan) bucket <source> and
        <target>
        
        module=osd perm=rw flags=
        
        :param source: goodchars= ``[A-Za-z0-9-_.]``
        :param dest: goodchars= ``[A-Za-z0-9-_.]``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd crush swap-bucket'
        _args = {'prefix': prefix, 'source': source, 'dest': dest, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_crush_tree(self, shadow: str=None):
        """
        Prefix: ``osd crush tree``
        
        dump crush buckets and items in a tree view
        
        module=osd perm=r flags=
        
        :param shadow: CephChoices strings=--show-shadow
        """
        prefix = 'osd crush tree'
        _args = {'prefix': prefix, 'shadow': shadow}
        return self._mon_command(_args)
    
    def osd_crush_tunables(self, profile: str):
        """
        Prefix: ``osd crush tunables``
        
        set crush tunables values to <profile>
        
        module=osd perm=rw flags=
        
        :param profile: CephChoices
            strings=legacy|argonaut|bobtail|firefly|hammer|jewel|optimal|default
        """
        prefix = 'osd crush tunables'
        _args = {'prefix': prefix, 'profile': profile}
        return self._mon_command(_args)
    
    def osd_crush_unlink(self, name: str, ancestor: str=None):
        """
        Prefix: ``osd crush unlink``
        
        unlink <name> from crush map (everywhere, or just at <ancestor>)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param ancestor: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd crush unlink'
        _args = {'prefix': prefix, 'name': name, 'ancestor': ancestor}
        return self._mon_command(_args)
    
    def osd_crush_weight_set_create(self, pool: str, mode: str):
        """
        Prefix: ``osd crush weight-set create``
        
        create a weight-set for a given pool
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param mode: CephChoices strings=flat|positional
        """
        prefix = 'osd crush weight-set create'
        _args = {'prefix': prefix, 'pool': pool, 'mode': mode}
        return self._mon_command(_args)
    
    def osd_crush_weight_set_create_compat(self):
        """
        Prefix: ``osd crush weight-set create-compat``
        
        create a default backward-compatible weight-set
        
        module=osd perm=rw flags=
        """
        prefix = 'osd crush weight-set create-compat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_weight_set_dump(self):
        """
        Prefix: ``osd crush weight-set dump``
        
        dump crush weight sets
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush weight-set dump'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_weight_set_ls(self):
        """
        Prefix: ``osd crush weight-set ls``
        
        list crush weight sets
        
        module=osd perm=r flags=
        """
        prefix = 'osd crush weight-set ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_crush_weight_set_reweight(self, pool: str, item: str, weight: List[float]):
        """
        Prefix: ``osd crush weight-set reweight``
        
        set weight for an item (bucket or osd) in a pool's weight-set
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param item:
        :param weight: CephFloat range= ``0.0``
        """
        prefix = 'osd crush weight-set reweight'
        _args = {'prefix': prefix, 'pool': pool, 'item': item, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_crush_weight_set_reweight_compat(self, item: str, weight: List[float]):
        """
        Prefix: ``osd crush weight-set reweight-compat``
        
        set weight for an item (bucket or osd) in the backward-compatible
        weight-set
        
        module=osd perm=rw flags=
        
        :param item:
        :param weight: CephFloat range= ``0.0``
        """
        prefix = 'osd crush weight-set reweight-compat'
        _args = {'prefix': prefix, 'item': item, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_crush_weight_set_rm(self, pool: str):
        """
        Prefix: ``osd crush weight-set rm``
        
        remove the weight-set for a given pool
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        """
        prefix = 'osd crush weight-set rm'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def osd_crush_weight_set_rm_compat(self):
        """
        Prefix: ``osd crush weight-set rm-compat``
        
        remove the backward-compatible weight-set
        
        module=osd perm=rw flags=
        """
        prefix = 'osd crush weight-set rm-compat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_deep_scrub(self, who: str):
        """
        Prefix: ``osd deep-scrub``
        
        initiate deep scrub on osd <who>, or use <all|any> to deep scrub all
        
        module=osd perm=rw flags=mgr
        
        :param who:
        """
        prefix = 'osd deep-scrub'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_destroy(self, id_1: str, force: bool=None, yes_i_really_mean_it:
                    bool=None):
        """
        Prefix: ``osd destroy``
        
        mark osd as being destroyed. Keeps the ID intact (allowing reuse), but
        removes cephx keys, config-key data and lockbox keys, rendering data
        permanently unreadable.
        
        module=osd perm=rw flags=mgr
        
        :param id_1: CephOsdName Real name is ``id``
        :param force: CephBool
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd destroy'
        _args = {'prefix': prefix, 'id': id_1, 'force': force, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_destroy_actual(self, id_1: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd destroy-actual``
        
        mark osd as being destroyed. Keeps the ID intact (allowing reuse), but
        removes cephx keys, config-key data and lockbox keys, rendering data
        permanently unreadable.
        
        module=osd perm=rw flags=hidden
        
        :param id_1: CephOsdName Real name is ``id``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd destroy-actual'
        _args = {'prefix': prefix, 'id': id_1, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_df(self, output_method: str=None, filter_by: str=None, filter:
               str=None):
        """
        Prefix: ``osd df``
        
        show OSD utilization
        
        module=osd perm=r flags=mgr
        
        :param output_method: CephChoices strings=plain|tree
        :param filter_by: CephChoices strings=class|name
        :param filter:
        """
        prefix = 'osd df'
        _args = {'prefix': prefix, 'output_method': output_method, 'filter_by': filter_by,
                 'filter': filter}
        return self._mon_command(_args)
    
    def osd_down(self, ids: List[str]):
        """
        Prefix: ``osd down``
        
        set osd(s) <id> [<id>...] down, or use <any|all> to set all osds down
        
        module=osd perm=rw flags=
        
        :param ids:
        """
        prefix = 'osd down'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_dump(self, epoch: int=None):
        """
        Prefix: ``osd dump``
        
        print summary of OSD map
        
        module=osd perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'osd dump'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def osd_erasure_code_profile_get(self, name: str):
        """
        Prefix: ``osd erasure-code-profile get``
        
        get erasure code profile <name>
        
        module=osd perm=r flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd erasure-code-profile get'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    def osd_erasure_code_profile_ls(self):
        """
        Prefix: ``osd erasure-code-profile ls``
        
        list all erasure code profiles
        
        module=osd perm=r flags=
        """
        prefix = 'osd erasure-code-profile ls'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_erasure_code_profile_rm(self, name: str):
        """
        Prefix: ``osd erasure-code-profile rm``
        
        remove erasure code profile <name>
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        """
        prefix = 'osd erasure-code-profile rm'
        _args = {'prefix': prefix, 'name': name}
        return self._mon_command(_args)
    
    def osd_erasure_code_profile_set(self, name: str, profile: List[str]=None, force: bool=None):
        """
        Prefix: ``osd erasure-code-profile set``
        
        create erasure code profile <name> with [<key[=value]> ...] pairs. Add
        a --force at the end to override an existing profile (VERY DANGEROUS)
        
        module=osd perm=rw flags=
        
        :param name: goodchars= ``[A-Za-z0-9-_.]``
        :param profile:
        :param force: CephBool
        """
        prefix = 'osd erasure-code-profile set'
        _args = {'prefix': prefix, 'name': name, 'profile': profile, 'force': force}
        return self._mon_command(_args)
    
    def osd_find(self, id_1: str):
        """
        Prefix: ``osd find``
        
        find osd <id> in the CRUSH map and show its location
        
        module=osd perm=r flags=
        
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd find'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_force_create_pg(self, pgid: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd force-create-pg``
        
        force creation of pg <pgid>
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd force-create-pg'
        _args = {'prefix': prefix, 'pgid': pgid, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_get_require_min_compat_client(self):
        """
        Prefix: ``osd get-require-min-compat-client``
        
        get the minimum client version we will maintain compatibility with
        
        module=osd perm=r flags=
        """
        prefix = 'osd get-require-min-compat-client'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_getcrushmap(self, epoch: int=None):
        """
        Prefix: ``osd getcrushmap``
        
        get CRUSH map
        
        module=osd perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'osd getcrushmap'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def osd_getmap(self, epoch: int=None):
        """
        Prefix: ``osd getmap``
        
        get OSD map
        
        module=osd perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'osd getmap'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def osd_getmaxosd(self):
        """
        Prefix: ``osd getmaxosd``
        
        show largest OSD id
        
        module=osd perm=r flags=
        """
        prefix = 'osd getmaxosd'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_in(self, ids: List[str]):
        """
        Prefix: ``osd in``
        
        set osd(s) <id> [<id>...] in, can use <any|all> to automatically set
        all previously out osds in
        
        module=osd perm=rw flags=
        
        :param ids:
        """
        prefix = 'osd in'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_last_stat_seq(self, id_1: str):
        """
        Prefix: ``osd last-stat-seq``
        
        get the last pg stats sequence number reported for this osd
        
        module=osd perm=r flags=
        
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd last-stat-seq'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_lost(self, id_1: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd lost``
        
        mark osd as permanently lost. THIS DESTROYS DATA IF NO MORE REPLICAS
        EXIST, BE CAREFUL
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd lost'
        _args = {'prefix': prefix, 'id': id_1, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_ls(self, epoch: int=None):
        """
        Prefix: ``osd ls``
        
        show all OSD ids
        
        module=osd perm=r flags=
        
        :param epoch: CephInt range= ``0``
        """
        prefix = 'osd ls'
        _args = {'prefix': prefix, 'epoch': epoch}
        return self._mon_command(_args)
    
    def osd_ls_tree(self, name: str, epoch: int=None):
        """
        Prefix: ``osd ls-tree``
        
        show OSD ids under bucket <name> in the CRUSH map
        
        module=osd perm=r flags=
        
        :param name:
        :param epoch: CephInt range= ``0``
        """
        prefix = 'osd ls-tree'
        _args = {'prefix': prefix, 'name': name, 'epoch': epoch}
        return self._mon_command(_args)
    
    @deprecated
    def osd_lspools(self):
        """
        Prefix: ``osd lspools``
        
        list pools
        
        module=osd perm=r flags=deprecated
        """
        prefix = 'osd lspools'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_map(self, pool: str, object: str, nspace: str=None):
        """
        Prefix: ``osd map``
        
        find pg for <object> in <pool> with [namespace]
        
        module=osd perm=r flags=
        
        :param pool: CephPoolname
        :param object: CephObjectname
        :param nspace:
        """
        prefix = 'osd map'
        _args = {'prefix': prefix, 'pool': pool, 'object': object, 'nspace': nspace}
        return self._mon_command(_args)
    
    def osd_metadata(self, id_1: str=None):
        """
        Prefix: ``osd metadata``
        
        fetch metadata for osd {id} (default all)
        
        module=osd perm=r flags=
        
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd metadata'
        _args = {'prefix': prefix, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_new(self, uuid: str, id_1: str=None):
        """
        Prefix: ``osd new``
        
        Create a new OSD. If supplied, the `id` to be replaced needs to exist
        and have been previously destroyed. Reads secrets from JSON file via
        `-i <file>` (see man page).
        
        module=osd perm=rw flags=
        
        :param uuid: CephUUID
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd new'
        _args = {'prefix': prefix, 'uuid': uuid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_numa_status(self):
        """
        Prefix: ``osd numa-status``
        
        show NUMA status of OSDs
        
        module=osd perm=r flags=
        """
        prefix = 'osd numa-status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_ok_to_stop(self, ids: List[str]):
        """
        Prefix: ``osd ok-to-stop``
        
        check whether osd(s) can be safely stopped without reducing immediate
        data availability
        
        module=osd perm=r flags=mgr
        
        :param ids:
        """
        prefix = 'osd ok-to-stop'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_out(self, ids: List[str]):
        """
        Prefix: ``osd out``
        
        set osd(s) <id> [<id>...] out, or use <any|all> to set all osds out
        
        module=osd perm=rw flags=
        
        :param ids:
        """
        prefix = 'osd out'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_pause(self):
        """
        Prefix: ``osd pause``
        
        pause osd
        
        module=osd perm=rw flags=
        """
        prefix = 'osd pause'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_perf(self):
        """
        Prefix: ``osd perf``
        
        print dump of OSD perf summary stats
        
        module=osd perm=r flags=mgr
        """
        prefix = 'osd perf'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_perf_counters_get(self, query_id: int):
        """
        Prefix: ``osd perf counters get``
        
        fetch osd perf counters
        
        module=mgr perm=w flags=mgr
        
        :param query_id: CephInt
        """
        prefix = 'osd perf counters get'
        _args = {'prefix': prefix, 'query_id': query_id}
        return self._mon_command(_args)
    
    def osd_perf_query_add(self, query: str):
        """
        Prefix: ``osd perf query add``
        
        add osd perf query
        
        module=mgr perm=w flags=mgr
        
        :param query: CephChoices strings=client_id|rbd_image_id|all_subkeys
        """
        prefix = 'osd perf query add'
        _args = {'prefix': prefix, 'query': query}
        return self._mon_command(_args)
    
    def osd_perf_query_remove(self, query_id: int):
        """
        Prefix: ``osd perf query remove``
        
        remove osd perf query
        
        module=mgr perm=w flags=mgr
        
        :param query_id: CephInt
        """
        prefix = 'osd perf query remove'
        _args = {'prefix': prefix, 'query_id': query_id}
        return self._mon_command(_args)
    
    def osd_pg_temp(self, pgid: str, id_1: List[str]=None):
        """
        Prefix: ``osd pg-temp``
        
        set pg_temp mapping pgid:[<id> [<id>...]] (developers only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd pg-temp'
        _args = {'prefix': prefix, 'pgid': pgid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_pg_upmap(self, pgid: str, id_1: List[str]):
        """
        Prefix: ``osd pg-upmap``
        
        set pg_upmap mapping <pgid>:[<id> [<id>...]] (developers only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd pg-upmap'
        _args = {'prefix': prefix, 'pgid': pgid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_pg_upmap_items(self, pgid: str, id_1: List[str]):
        """
        Prefix: ``osd pg-upmap-items``
        
        set pg_upmap_items mapping <pgid>:{<id> to <id>, [...]} (developers
        only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd pg-upmap-items'
        _args = {'prefix': prefix, 'pgid': pgid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_pool_application_disable(self, pool: str, app: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd pool application disable``
        
        disables use of an application <app> on pool <poolname>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param app:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd pool application disable'
        _args = {'prefix': prefix, 'pool': pool, 'app': app, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_pool_application_enable(self, pool: str, app: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd pool application enable``
        
        enable use of an application <app> [cephfs,rbd,rgw] on pool <poolname>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param app: goodchars= ``[A-Za-z0-9-_.]``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd pool application enable'
        _args = {'prefix': prefix, 'pool': pool, 'app': app, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_pool_application_get(self, pool: str, app: str=None, key: str=None):
        """
        Prefix: ``osd pool application get``
        
        get value of key <key> of application <app> on pool <poolname>
        
        module=osd perm=r flags=
        
        :param pool: CephPoolname
        :param app:
        :param key:
        """
        prefix = 'osd pool application get'
        _args = {'prefix': prefix, 'pool': pool, 'app': app, 'key': key}
        return self._mon_command(_args)
    
    def osd_pool_application_rm(self, pool: str, app: str, key: str):
        """
        Prefix: ``osd pool application rm``
        
        removes application <app> metadata key <key> on pool <poolname>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param app:
        :param key:
        """
        prefix = 'osd pool application rm'
        _args = {'prefix': prefix, 'pool': pool, 'app': app, 'key': key}
        return self._mon_command(_args)
    
    def osd_pool_application_set(self, pool: str, app: str, key: str, value: str):
        """
        Prefix: ``osd pool application set``
        
        sets application <app> metadata key <key> to <value> on pool
        <poolname>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param app:
        :param key: goodchars= ``[A-Za-z0-9-_.]``
        :param value: goodchars= ``[A-Za-z0-9-_.=]``
        """
        prefix = 'osd pool application set'
        _args = {'prefix': prefix, 'pool': pool, 'app': app, 'key': key, 'value': value}
        return self._mon_command(_args)
    
    def osd_pool_autoscale_status(self):
        """
        Prefix: ``osd pool autoscale-status``
        
        report on pool pg_num sizing recommendation and intent
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'osd pool autoscale-status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_pool_cancel_force_backfill(self, who: List[str]):
        """
        Prefix: ``osd pool cancel-force-backfill``
        
        restore normal recovery priority of specified pool <who>
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool cancel-force-backfill'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_cancel_force_recovery(self, who: List[str]):
        """
        Prefix: ``osd pool cancel-force-recovery``
        
        restore normal recovery priority of specified pool <who>
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool cancel-force-recovery'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_create(self, pool: str, pg_num: int, pgp_num: int=None, pool_type:
                        str=None, erasure_code_profile: str=None, rule: str=None,
                        expected_num_objects: int=None, size: int=None, pg_num_min:
                        int=None, target_size_bytes: int=None, target_size_ratio:
                        float=None):
        """
        Prefix: ``osd pool create``
        
        create pool
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param pg_num: CephInt range= ``0``
        :param pgp_num: CephInt range= ``0``
        :param pool_type: CephChoices strings=replicated|erasure
        :param erasure_code_profile: goodchars= ``[A-Za-z0-9-_.]``
        :param rule:
        :param expected_num_objects: CephInt
        :param size: CephInt
        :param pg_num_min: CephInt range= ``0``
        :param target_size_bytes: CephInt range= ``0``
        :param target_size_ratio: CephFloat range= ``0..1``
        """
        prefix = 'osd pool create'
        _args = {'prefix': prefix, 'pool': pool, 'pg_num': pg_num, 'pgp_num': pgp_num,
                 'pool_type': pool_type, 'erasure_code_profile':
                 erasure_code_profile, 'rule': rule, 'expected_num_objects':
                 expected_num_objects, 'size': size, 'pg_num_min':
                 pg_num_min, 'target_size_bytes': target_size_bytes,
                 'target_size_ratio': target_size_ratio}
        return self._mon_command(_args)
    
    def osd_pool_deep_scrub(self, who: List[str]):
        """
        Prefix: ``osd pool deep-scrub``
        
        initiate deep-scrub on pool <who>
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool deep-scrub'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    @deprecated
    def osd_pool_delete(self, pool: str, pool2: str=None,
                        yes_i_really_really_mean_it: bool=None,
                        yes_i_really_really_mean_it_not_faking: bool=None):
        """
        Prefix: ``osd pool delete``
        
        delete pool
        
        module=osd perm=rw flags=deprecated
        
        :param pool: CephPoolname
        :param pool2: CephPoolname
        :param yes_i_really_really_mean_it: CephBool
        :param yes_i_really_really_mean_it_not_faking: CephBool
        """
        prefix = 'osd pool delete'
        _args = {'prefix': prefix, 'pool': pool, 'pool2': pool2, 'yes_i_really_really_mean_it':
                 yes_i_really_really_mean_it,
                 'yes_i_really_really_mean_it_not_faking':
                 yes_i_really_really_mean_it_not_faking}
        return self._mon_command(_args)
    
    def osd_pool_force_backfill(self, who: List[str]):
        """
        Prefix: ``osd pool force-backfill``
        
        force backfill of specified pool <who> first
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool force-backfill'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_force_recovery(self, who: List[str]):
        """
        Prefix: ``osd pool force-recovery``
        
        force recovery of specified pool <who> first
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool force-recovery'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_get(self, pool: str, var: str):
        """
        Prefix: ``osd pool get``
        
        get pool parameter <var>
        
        module=osd perm=r flags=
        
        :param pool: CephPoolname
        :param var: CephChoices strings=size|min_size|pg_num|pgp_num|crush_rul
            e|hashpspool|nodelete|nopgchange|nosizechange|write_fadvise_dontneed|n
            oscrub|nodeep-scrub|hit_set_type|hit_set_period|hit_set_count|hit_set_
            fpp|use_gmt_hitset|target_max_objects|target_max_bytes|cache_target_di
            rty_ratio|cache_target_dirty_high_ratio|cache_target_full_ratio|cache_
            min_flush_age|cache_min_evict_age|erasure_code_profile|min_read_recenc
            y_for_promote|all|min_write_recency_for_promote|fast_read|hit_set_grad
            e_decay_rate|hit_set_search_last_n|scrub_min_interval|scrub_max_interv
            al|deep_scrub_interval|recovery_priority|recovery_op_priority|scrub_pr
            iority|compression_mode|compression_algorithm|compression_required_rat
            io|compression_max_blob_size|compression_min_blob_size|csum_type|csum_
            min_block|csum_max_block|allow_ec_overwrites|fingerprint_algorithm|pg_
            autoscale_mode|pg_autoscale_bias|pg_num_min|target_size_bytes|target_s
            ize_ratio
        """
        prefix = 'osd pool get'
        _args = {'prefix': prefix, 'pool': pool, 'var': var}
        return self._mon_command(_args)
    
    def osd_pool_get_quota(self, pool: str):
        """
        Prefix: ``osd pool get-quota``
        
        obtain object or byte limits for pool
        
        module=osd perm=r flags=
        
        :param pool: CephPoolname
        """
        prefix = 'osd pool get-quota'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def osd_pool_ls(self, detail: str=None):
        """
        Prefix: ``osd pool ls``
        
        list pools
        
        module=osd perm=r flags=
        
        :param detail: CephChoices strings=detail
        """
        prefix = 'osd pool ls'
        _args = {'prefix': prefix, 'detail': detail}
        return self._mon_command(_args)
    
    def osd_pool_mksnap(self, pool: str, snap: str):
        """
        Prefix: ``osd pool mksnap``
        
        make snapshot <snap> in <pool>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param snap:
        """
        prefix = 'osd pool mksnap'
        _args = {'prefix': prefix, 'pool': pool, 'snap': snap}
        return self._mon_command(_args)
    
    def osd_pool_rename(self, srcpool: str, destpool: str):
        """
        Prefix: ``osd pool rename``
        
        rename <srcpool> to <destpool>
        
        module=osd perm=rw flags=
        
        :param srcpool: CephPoolname
        :param destpool: CephPoolname
        """
        prefix = 'osd pool rename'
        _args = {'prefix': prefix, 'srcpool': srcpool, 'destpool': destpool}
        return self._mon_command(_args)
    
    def osd_pool_repair(self, who: List[str]):
        """
        Prefix: ``osd pool repair``
        
        initiate repair on pool <who>
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool repair'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_rm(self, pool: str, pool2: str=None,
                    yes_i_really_really_mean_it: bool=None,
                    yes_i_really_really_mean_it_not_faking: bool=None):
        """
        Prefix: ``osd pool rm``
        
        remove pool
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param pool2: CephPoolname
        :param yes_i_really_really_mean_it: CephBool
        :param yes_i_really_really_mean_it_not_faking: CephBool
        """
        prefix = 'osd pool rm'
        _args = {'prefix': prefix, 'pool': pool, 'pool2': pool2, 'yes_i_really_really_mean_it':
                 yes_i_really_really_mean_it,
                 'yes_i_really_really_mean_it_not_faking':
                 yes_i_really_really_mean_it_not_faking}
        return self._mon_command(_args)
    
    def osd_pool_rmsnap(self, pool: str, snap: str):
        """
        Prefix: ``osd pool rmsnap``
        
        remove snapshot <snap> from <pool>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param snap:
        """
        prefix = 'osd pool rmsnap'
        _args = {'prefix': prefix, 'pool': pool, 'snap': snap}
        return self._mon_command(_args)
    
    def osd_pool_scrub(self, who: List[str]):
        """
        Prefix: ``osd pool scrub``
        
        initiate scrub on pool <who>
        
        module=osd perm=rw flags=mgr
        
        :param who: CephPoolname
        """
        prefix = 'osd pool scrub'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_pool_set(self, pool: str, var: str, val: str, yes_i_really_mean_it:
                     bool=None):
        """
        Prefix: ``osd pool set``
        
        set pool parameter <var> to <val>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param var: CephChoices strings=size|min_size|pg_num|pgp_num|pgp_num_a
            ctual|crush_rule|hashpspool|nodelete|nopgchange|nosizechange|write_fad
            vise_dontneed|noscrub|nodeep-scrub|hit_set_type|hit_set_period|hit_set
            _count|hit_set_fpp|use_gmt_hitset|target_max_bytes|target_max_objects|
            cache_target_dirty_ratio|cache_target_dirty_high_ratio|cache_target_fu
            ll_ratio|cache_min_flush_age|cache_min_evict_age|min_read_recency_for_
            promote|min_write_recency_for_promote|fast_read|hit_set_grade_decay_ra
            te|hit_set_search_last_n|scrub_min_interval|scrub_max_interval|deep_sc
            rub_interval|recovery_priority|recovery_op_priority|scrub_priority|com
            pression_mode|compression_algorithm|compression_required_ratio|compres
            sion_max_blob_size|compression_min_blob_size|csum_type|csum_min_block|
            csum_max_block|allow_ec_overwrites|fingerprint_algorithm|pg_autoscale_
            mode|pg_autoscale_bias|pg_num_min|target_size_bytes|target_size_ratio
        :param val:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd pool set'
        _args = {'prefix': prefix, 'pool': pool, 'var': var, 'val': val,
                 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_pool_set_quota(self, pool: str, field: str, val: str):
        """
        Prefix: ``osd pool set-quota``
        
        set object or byte limit on pool
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param field: CephChoices strings=max_objects|max_bytes
        :param val:
        """
        prefix = 'osd pool set-quota'
        _args = {'prefix': prefix, 'pool': pool, 'field': field, 'val': val}
        return self._mon_command(_args)
    
    def osd_pool_stats(self, pool_name: str=None):
        """
        Prefix: ``osd pool stats``
        
        obtain stats from all pools, or from specified pool
        
        module=osd perm=r flags=mgr
        
        :param pool_name: CephPoolname
        """
        prefix = 'osd pool stats'
        _args = {'prefix': prefix, 'pool_name': pool_name}
        return self._mon_command(_args)
    
    def osd_primary_affinity(self, id_1: str, weight: float):
        """
        Prefix: ``osd primary-affinity``
        
        adjust osd primary-affinity from 0.0 <= <weight> <= 1.0
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param weight: CephFloat range= ``0.0..1.0``
        """
        prefix = 'osd primary-affinity'
        _args = {'prefix': prefix, 'id': id_1, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_primary_temp(self, pgid: str, id_1: str):
        """
        Prefix: ``osd primary-temp``
        
        set primary_temp mapping pgid:<id>|-1 (developers only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        :param id_1: CephOsdName Real name is ``id``
        """
        prefix = 'osd primary-temp'
        _args = {'prefix': prefix, 'pgid': pgid, 'id': id_1}
        return self._mon_command(_args)
    
    def osd_purge(self, id_1: str, force: bool=None, yes_i_really_mean_it:
                  bool=None):
        """
        Prefix: ``osd purge``
        
        purge all osd data from the monitors including the OSD id and CRUSH
        position
        
        module=osd perm=rw flags=mgr
        
        :param id_1: CephOsdName Real name is ``id``
        :param force: CephBool
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd purge'
        _args = {'prefix': prefix, 'id': id_1, 'force': force, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_purge_actual(self, id_1: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd purge-actual``
        
        purge all osd data from the monitors. Combines `osd destroy`, `osd
        rm`, and `osd crush rm`.
        
        module=osd perm=rw flags=hidden
        
        :param id_1: CephOsdName Real name is ``id``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd purge-actual'
        _args = {'prefix': prefix, 'id': id_1, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_purge_new(self, id_1: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd purge-new``
        
        purge all traces of an OSD that was partially created but never
        started
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd purge-new'
        _args = {'prefix': prefix, 'id': id_1, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_repair(self, who: str):
        """
        Prefix: ``osd repair``
        
        initiate repair on osd <who>, or use <all|any> to repair all
        
        module=osd perm=rw flags=mgr
        
        :param who:
        """
        prefix = 'osd repair'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_require_osd_release(self, release: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd require-osd-release``
        
        set the minimum allowed OSD release to participate in the cluster
        
        module=osd perm=rw flags=
        
        :param release: CephChoices strings=luminous|mimic|nautilus|octopus
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd require-osd-release'
        _args = {'prefix': prefix, 'release': release, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_reweight(self, id_1: str, weight: float):
        """
        Prefix: ``osd reweight``
        
        reweight osd to 0.0 < <weight> < 1.0
        
        module=osd perm=rw flags=
        
        :param id_1: CephOsdName Real name is ``id``
        :param weight: CephFloat range= ``0.0..1.0``
        """
        prefix = 'osd reweight'
        _args = {'prefix': prefix, 'id': id_1, 'weight': weight}
        return self._mon_command(_args)
    
    def osd_reweight_by_pg(self, oload: int=None, max_change: float=None, max_osds:
                           int=None, pools: List[str]=None):
        """
        Prefix: ``osd reweight-by-pg``
        
        reweight OSDs by PG distribution [overload-percentage-for-
        consideration, default 120]
        
        module=osd perm=rw flags=mgr
        
        :param oload: CephInt
        :param max_change: CephFloat
        :param max_osds: CephInt
        :param pools: CephPoolname
        """
        prefix = 'osd reweight-by-pg'
        _args = {'prefix': prefix, 'oload': oload, 'max_change': max_change, 'max_osds':
                 max_osds, 'pools': pools}
        return self._mon_command(_args)
    
    def osd_reweight_by_utilization(self, oload: int=None, max_change: float=None, max_osds:
                                    int=None, no_increasing: str=None):
        """
        Prefix: ``osd reweight-by-utilization``
        
        reweight OSDs by utilization [overload-percentage-for-consideration,
        default 120]
        
        module=osd perm=rw flags=mgr
        
        :param oload: CephInt
        :param max_change: CephFloat
        :param max_osds: CephInt
        :param no_increasing: CephChoices strings=--no-increasing
        """
        prefix = 'osd reweight-by-utilization'
        _args = {'prefix': prefix, 'oload': oload, 'max_change': max_change, 'max_osds':
                 max_osds, 'no_increasing': no_increasing}
        return self._mon_command(_args)
    
    def osd_reweightn(self, weights: str):
        """
        Prefix: ``osd reweightn``
        
        reweight osds with {<id>: <weight>,...})
        
        module=osd perm=rw flags=
        
        :param weights:
        """
        prefix = 'osd reweightn'
        _args = {'prefix': prefix, 'weights': weights}
        return self._mon_command(_args)
    
    @deprecated
    def osd_rm(self, ids: List[str]):
        """
        Prefix: ``osd rm``
        
        remove osd(s) <id> [<id>...], or use <any|all> to remove all osds
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd rm'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_rm_nodown(self, ids: List[str]):
        """
        Prefix: ``osd rm-nodown``
        
        allow osd(s) <id> [<id>...] to be marked down (if they are currently
        marked as nodown), can use <all|any> to automatically filter out all
        nodown osds
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd rm-nodown'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_rm_noin(self, ids: List[str]):
        """
        Prefix: ``osd rm-noin``
        
        allow osd(s) <id> [<id>...] to be marked in (if they are currently
        marked as noin), can use <all|any> to automatically filter out all
        noin osds
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd rm-noin'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_rm_noout(self, ids: List[str]):
        """
        Prefix: ``osd rm-noout``
        
        allow osd(s) <id> [<id>...] to be marked out (if they are currently
        marked as noout), can use <all|any> to automatically filter out all
        noout osds
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd rm-noout'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    @deprecated
    def osd_rm_noup(self, ids: List[str]):
        """
        Prefix: ``osd rm-noup``
        
        allow osd(s) <id> [<id>...] to be marked up (if they are currently
        marked as noup), can use <all|any> to automatically filter out all
        noup osds
        
        module=osd perm=rw flags=deprecated
        
        :param ids:
        """
        prefix = 'osd rm-noup'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_rm_pg_upmap(self, pgid: str):
        """
        Prefix: ``osd rm-pg-upmap``
        
        clear pg_upmap mapping for <pgid> (developers only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        """
        prefix = 'osd rm-pg-upmap'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def osd_rm_pg_upmap_items(self, pgid: str):
        """
        Prefix: ``osd rm-pg-upmap-items``
        
        clear pg_upmap_items mapping for <pgid> (developers only)
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        """
        prefix = 'osd rm-pg-upmap-items'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def osd_safe_to_destroy(self, ids: List[str]):
        """
        Prefix: ``osd safe-to-destroy``
        
        check whether osd(s) can be safely destroyed without reducing data
        durability
        
        module=osd perm=r flags=mgr
        
        :param ids:
        """
        prefix = 'osd safe-to-destroy'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_scrub(self, who: str):
        """
        Prefix: ``osd scrub``
        
        initiate scrub on osd <who>, or use <all|any> to scrub all
        
        module=osd perm=rw flags=mgr
        
        :param who:
        """
        prefix = 'osd scrub'
        _args = {'prefix': prefix, 'who': who}
        return self._mon_command(_args)
    
    def osd_set(self, key: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd set``
        
        set <key>
        
        module=osd perm=rw flags=
        
        :param key: CephChoices strings=full|pause|noup|nodown|noout|noin|noba
            ckfill|norebalance|norecover|noscrub|nodeep-
            scrub|notieragent|nosnaptrim|pglog_hardlimit
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd set'
        _args = {'prefix': prefix, 'key': key, 'yes_i_really_mean_it': yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_set_backfillfull_ratio(self, ratio: float):
        """
        Prefix: ``osd set-backfillfull-ratio``
        
        set usage ratio at which OSDs are marked too full to backfill
        
        module=osd perm=rw flags=
        
        :param ratio: CephFloat range= ``0.0..1.0``
        """
        prefix = 'osd set-backfillfull-ratio'
        _args = {'prefix': prefix, 'ratio': ratio}
        return self._mon_command(_args)
    
    def osd_set_full_ratio(self, ratio: float):
        """
        Prefix: ``osd set-full-ratio``
        
        set usage ratio at which OSDs are marked full
        
        module=osd perm=rw flags=
        
        :param ratio: CephFloat range= ``0.0..1.0``
        """
        prefix = 'osd set-full-ratio'
        _args = {'prefix': prefix, 'ratio': ratio}
        return self._mon_command(_args)
    
    def osd_set_group(self, flags: str, who: List[str]):
        """
        Prefix: ``osd set-group``
        
        set <flags> for batch osds or crush nodes, <flags> must be a comma-
        separated subset of {noup,nodown,noin,noout}
        
        module=osd perm=rw flags=
        
        :param flags:
        :param who:
        """
        prefix = 'osd set-group'
        _args = {'prefix': prefix, 'flags': flags, 'who': who}
        return self._mon_command(_args)
    
    def osd_set_nearfull_ratio(self, ratio: float):
        """
        Prefix: ``osd set-nearfull-ratio``
        
        set usage ratio at which OSDs are marked near-full
        
        module=osd perm=rw flags=
        
        :param ratio: CephFloat range= ``0.0..1.0``
        """
        prefix = 'osd set-nearfull-ratio'
        _args = {'prefix': prefix, 'ratio': ratio}
        return self._mon_command(_args)
    
    def osd_set_require_min_compat_client(self, version: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd set-require-min-compat-client``
        
        set the minimum client version we will maintain compatibility with
        
        module=osd perm=rw flags=
        
        :param version:
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd set-require-min-compat-client'
        _args = {'prefix': prefix, 'version': version, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    def osd_setcrushmap(self, prior_version: int=None):
        """
        Prefix: ``osd setcrushmap``
        
        set crush map from input file
        
        module=osd perm=rw flags=
        
        :param prior_version: CephInt
        """
        prefix = 'osd setcrushmap'
        _args = {'prefix': prefix, 'prior_version': prior_version}
        return self._mon_command(_args)
    
    def osd_setmaxosd(self, newmax: int):
        """
        Prefix: ``osd setmaxosd``
        
        set new maximum osd value
        
        module=osd perm=rw flags=
        
        :param newmax: CephInt range= ``0``
        """
        prefix = 'osd setmaxosd'
        _args = {'prefix': prefix, 'newmax': newmax}
        return self._mon_command(_args)
    
    def osd_stat(self):
        """
        Prefix: ``osd stat``
        
        print summary of OSD map
        
        module=osd perm=r flags=
        """
        prefix = 'osd stat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_status(self, bucket: str=None):
        """
        Prefix: ``osd status``
        
        Show the status of OSDs within a bucket, or all
        
        module=mgr perm=r flags=mgr
        
        :param bucket:
        """
        prefix = 'osd status'
        _args = {'prefix': prefix, 'bucket': bucket}
        return self._mon_command(_args)
    
    def osd_stop(self, ids: List[str]):
        """
        Prefix: ``osd stop``
        
        stop the corresponding osd daemons and mark them as down
        
        module=osd perm=rw flags=
        
        :param ids:
        """
        prefix = 'osd stop'
        _args = {'prefix': prefix, 'ids': ids}
        return self._mon_command(_args)
    
    def osd_test_reweight_by_pg(self, oload: int=None, max_change: float=None, max_osds:
                                int=None, pools: List[str]=None):
        """
        Prefix: ``osd test-reweight-by-pg``
        
        dry run of reweight OSDs by PG distribution [overload-percentage-for-
        consideration, default 120]
        
        module=osd perm=r flags=mgr
        
        :param oload: CephInt
        :param max_change: CephFloat
        :param max_osds: CephInt
        :param pools: CephPoolname
        """
        prefix = 'osd test-reweight-by-pg'
        _args = {'prefix': prefix, 'oload': oload, 'max_change': max_change, 'max_osds':
                 max_osds, 'pools': pools}
        return self._mon_command(_args)
    
    def osd_test_reweight_by_utilization(self, oload: int=None, max_change: float=None, max_osds:
                                         int=None, no_increasing: bool=None):
        """
        Prefix: ``osd test-reweight-by-utilization``
        
        dry run of reweight OSDs by utilization [overload-percentage-for-
        consideration, default 120]
        
        module=osd perm=r flags=mgr
        
        :param oload: CephInt
        :param max_change: CephFloat
        :param max_osds: CephInt
        :param no_increasing: CephBool
        """
        prefix = 'osd test-reweight-by-utilization'
        _args = {'prefix': prefix, 'oload': oload, 'max_change': max_change, 'max_osds':
                 max_osds, 'no_increasing': no_increasing}
        return self._mon_command(_args)
    
    def osd_tier_add(self, pool: str, tierpool: str, force_nonempty: str=None):
        """
        Prefix: ``osd tier add``
        
        add the tier <tierpool> (the second one) to base pool <pool> (the
        first one)
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param tierpool: CephPoolname
        :param force_nonempty: CephChoices strings=--force-nonempty
        """
        prefix = 'osd tier add'
        _args = {'prefix': prefix, 'pool': pool, 'tierpool': tierpool, 'force_nonempty':
                 force_nonempty}
        return self._mon_command(_args)
    
    def osd_tier_add_cache(self, pool: str, tierpool: str, size: int):
        """
        Prefix: ``osd tier add-cache``
        
        add a cache <tierpool> (the second one) of size <size> to existing
        pool <pool> (the first one)
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param tierpool: CephPoolname
        :param size: CephInt range= ``0``
        """
        prefix = 'osd tier add-cache'
        _args = {'prefix': prefix, 'pool': pool, 'tierpool': tierpool, 'size': size}
        return self._mon_command(_args)
    
    def osd_tier_cache_mode(self, pool: str, mode: str, yes_i_really_mean_it: bool=None):
        """
        Prefix: ``osd tier cache-mode``
        
        specify the caching mode for cache tier <pool>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param mode: CephChoices
            strings=none|writeback|forward|readonly|readforward|proxy|readproxy
        :param yes_i_really_mean_it: CephBool
        """
        prefix = 'osd tier cache-mode'
        _args = {'prefix': prefix, 'pool': pool, 'mode': mode, 'yes_i_really_mean_it':
                 yes_i_really_mean_it}
        return self._mon_command(_args)
    
    @deprecated
    def osd_tier_remove(self, pool: str, tierpool: str):
        """
        Prefix: ``osd tier remove``
        
        remove the tier <tierpool> (the second one) from base pool <pool> (the
        first one)
        
        module=osd perm=rw flags=deprecated
        
        :param pool: CephPoolname
        :param tierpool: CephPoolname
        """
        prefix = 'osd tier remove'
        _args = {'prefix': prefix, 'pool': pool, 'tierpool': tierpool}
        return self._mon_command(_args)
    
    @deprecated
    def osd_tier_remove_overlay(self, pool: str):
        """
        Prefix: ``osd tier remove-overlay``
        
        remove the overlay pool for base pool <pool>
        
        module=osd perm=rw flags=deprecated
        
        :param pool: CephPoolname
        """
        prefix = 'osd tier remove-overlay'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def osd_tier_rm(self, pool: str, tierpool: str):
        """
        Prefix: ``osd tier rm``
        
        remove the tier <tierpool> (the second one) from base pool <pool> (the
        first one)
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param tierpool: CephPoolname
        """
        prefix = 'osd tier rm'
        _args = {'prefix': prefix, 'pool': pool, 'tierpool': tierpool}
        return self._mon_command(_args)
    
    def osd_tier_rm_overlay(self, pool: str):
        """
        Prefix: ``osd tier rm-overlay``
        
        remove the overlay pool for base pool <pool>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        """
        prefix = 'osd tier rm-overlay'
        _args = {'prefix': prefix, 'pool': pool}
        return self._mon_command(_args)
    
    def osd_tier_set_overlay(self, pool: str, overlaypool: str):
        """
        Prefix: ``osd tier set-overlay``
        
        set the overlay pool for base pool <pool> to be <overlaypool>
        
        module=osd perm=rw flags=
        
        :param pool: CephPoolname
        :param overlaypool: CephPoolname
        """
        prefix = 'osd tier set-overlay'
        _args = {'prefix': prefix, 'pool': pool, 'overlaypool': overlaypool}
        return self._mon_command(_args)
    
    def osd_tree(self, epoch: int=None, states: List[str]=None):
        """
        Prefix: ``osd tree``
        
        print OSD tree
        
        module=osd perm=r flags=
        
        :param epoch: CephInt range= ``0``
        :param states: CephChoices strings=up|down|in|out|destroyed
        """
        prefix = 'osd tree'
        _args = {'prefix': prefix, 'epoch': epoch, 'states': states}
        return self._mon_command(_args)
    
    def osd_tree_from(self, bucket: str, epoch: int=None, states: List[str]=None):
        """
        Prefix: ``osd tree-from``
        
        print OSD tree in bucket
        
        module=osd perm=r flags=
        
        :param bucket:
        :param epoch: CephInt range= ``0``
        :param states: CephChoices strings=up|down|in|out|destroyed
        """
        prefix = 'osd tree-from'
        _args = {'prefix': prefix, 'bucket': bucket, 'epoch': epoch, 'states': states}
        return self._mon_command(_args)
    
    def osd_unpause(self):
        """
        Prefix: ``osd unpause``
        
        unpause osd
        
        module=osd perm=rw flags=
        """
        prefix = 'osd unpause'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_unset(self, key: str):
        """
        Prefix: ``osd unset``
        
        unset <key>
        
        module=osd perm=rw flags=
        
        :param key: CephChoices strings=full|pause|noup|nodown|noout|noin|noba
            ckfill|norebalance|norecover|noscrub|nodeep-
            scrub|notieragent|nosnaptrim
        """
        prefix = 'osd unset'
        _args = {'prefix': prefix, 'key': key}
        return self._mon_command(_args)
    
    def osd_unset_group(self, flags: str, who: List[str]):
        """
        Prefix: ``osd unset-group``
        
        unset <flags> for batch osds or crush nodes, <flags> must be a comma-
        separated subset of {noup,nodown,noin,noout}
        
        module=osd perm=rw flags=
        
        :param flags:
        :param who:
        """
        prefix = 'osd unset-group'
        _args = {'prefix': prefix, 'flags': flags, 'who': who}
        return self._mon_command(_args)
    
    def osd_utilization(self):
        """
        Prefix: ``osd utilization``
        
        get basic pg distribution stats
        
        module=osd perm=r flags=
        """
        prefix = 'osd utilization'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def osd_versions(self):
        """
        Prefix: ``osd versions``
        
        check running versions of OSDs
        
        module=osd perm=r flags=
        """
        prefix = 'osd versions'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def pg_cancel_force_backfill(self, pgid: List[str]):
        """
        Prefix: ``pg cancel-force-backfill``
        
        restore normal backfill priority of <pgid>
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg cancel-force-backfill'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_cancel_force_recovery(self, pgid: List[str]):
        """
        Prefix: ``pg cancel-force-recovery``
        
        restore normal recovery priority of <pgid>
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg cancel-force-recovery'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_debug(self, debugop: str):
        """
        Prefix: ``pg debug``
        
        show debug info about pgs
        
        module=pg perm=r flags=mgr
        
        :param debugop: CephChoices
            strings=unfound_objects_exist|degraded_pgs_exist
        """
        prefix = 'pg debug'
        _args = {'prefix': prefix, 'debugop': debugop}
        return self._mon_command(_args)
    
    def pg_deep_scrub(self, pgid: str):
        """
        Prefix: ``pg deep-scrub``
        
        start deep-scrub on <pgid>
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg deep-scrub'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_dump(self, dumpcontents: List[str]=None):
        """
        Prefix: ``pg dump``
        
        show human-readable versions of pg map (only 'all' valid with plain)
        
        module=pg perm=r flags=mgr
        
        :param dumpcontents: CephChoices
            strings=all|summary|sum|delta|pools|osds|pgs|pgs_brief
        """
        prefix = 'pg dump'
        _args = {'prefix': prefix, 'dumpcontents': dumpcontents}
        return self._mon_command(_args)
    
    def pg_dump_json(self, dumpcontents: List[str]=None):
        """
        Prefix: ``pg dump_json``
        
        show human-readable version of pg map in json only
        
        module=pg perm=r flags=mgr
        
        :param dumpcontents: CephChoices
            strings=all|summary|sum|pools|osds|pgs
        """
        prefix = 'pg dump_json'
        _args = {'prefix': prefix, 'dumpcontents': dumpcontents}
        return self._mon_command(_args)
    
    def pg_dump_pools_json(self):
        """
        Prefix: ``pg dump_pools_json``
        
        show pg pools info in json only
        
        module=pg perm=r flags=mgr
        """
        prefix = 'pg dump_pools_json'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def pg_dump_stuck(self, stuckops: List[str]=None, threshold: int=None):
        """
        Prefix: ``pg dump_stuck``
        
        show information about stuck pgs
        
        module=pg perm=r flags=mgr
        
        :param stuckops: CephChoices
            strings=inactive|unclean|stale|undersized|degraded
        :param threshold: CephInt
        """
        prefix = 'pg dump_stuck'
        _args = {'prefix': prefix, 'stuckops': stuckops, 'threshold': threshold}
        return self._mon_command(_args)
    
    def pg_force_backfill(self, pgid: List[str]):
        """
        Prefix: ``pg force-backfill``
        
        force backfill of <pgid> first
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg force-backfill'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_force_recovery(self, pgid: List[str]):
        """
        Prefix: ``pg force-recovery``
        
        force recovery of <pgid> first
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg force-recovery'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_getmap(self):
        """
        Prefix: ``pg getmap``
        
        get binary pg map to -o/stdout
        
        module=pg perm=r flags=mgr
        """
        prefix = 'pg getmap'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def pg_ls(self, pool: int=None, states: List[str]=None):
        """
        Prefix: ``pg ls``
        
        list pg with specific pool, osd, state
        
        module=pg perm=r flags=mgr
        
        :param pool: CephInt
        :param states:
        """
        prefix = 'pg ls'
        _args = {'prefix': prefix, 'pool': pool, 'states': states}
        return self._mon_command(_args)
    
    def pg_ls_by_osd(self, osd: str, pool: int=None, states: List[str]=None):
        """
        Prefix: ``pg ls-by-osd``
        
        list pg on osd [osd]
        
        module=pg perm=r flags=mgr
        
        :param osd: CephOsdName
        :param pool: CephInt
        :param states:
        """
        prefix = 'pg ls-by-osd'
        _args = {'prefix': prefix, 'osd': osd, 'pool': pool, 'states': states}
        return self._mon_command(_args)
    
    def pg_ls_by_pool(self, poolstr: str, states: List[str]=None):
        """
        Prefix: ``pg ls-by-pool``
        
        list pg with pool = [poolname]
        
        module=pg perm=r flags=mgr
        
        :param poolstr:
        :param states:
        """
        prefix = 'pg ls-by-pool'
        _args = {'prefix': prefix, 'poolstr': poolstr, 'states': states}
        return self._mon_command(_args)
    
    def pg_ls_by_primary(self, osd: str, pool: int=None, states: List[str]=None):
        """
        Prefix: ``pg ls-by-primary``
        
        list pg with primary = [osd]
        
        module=pg perm=r flags=mgr
        
        :param osd: CephOsdName
        :param pool: CephInt
        :param states:
        """
        prefix = 'pg ls-by-primary'
        _args = {'prefix': prefix, 'osd': osd, 'pool': pool, 'states': states}
        return self._mon_command(_args)
    
    def pg_map(self, pgid: str):
        """
        Prefix: ``pg map``
        
        show mapping of pg to osds
        
        module=pg perm=r flags=
        
        :param pgid: CephPgid
        """
        prefix = 'pg map'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_repair(self, pgid: str):
        """
        Prefix: ``pg repair``
        
        start repair on <pgid>
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg repair'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_repeer(self, pgid: str):
        """
        Prefix: ``pg repeer``
        
        force a PG to repeer
        
        module=osd perm=rw flags=
        
        :param pgid: CephPgid
        """
        prefix = 'pg repeer'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_scrub(self, pgid: str):
        """
        Prefix: ``pg scrub``
        
        start scrub on <pgid>
        
        module=pg perm=rw flags=mgr
        
        :param pgid: CephPgid
        """
        prefix = 'pg scrub'
        _args = {'prefix': prefix, 'pgid': pgid}
        return self._mon_command(_args)
    
    def pg_stat(self):
        """
        Prefix: ``pg stat``
        
        show placement group status.
        
        module=pg perm=r flags=mgr
        """
        prefix = 'pg stat'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def progress(self):
        """
        Prefix: ``progress``
        
        Show progress of recovery operations
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'progress'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def progress_clear(self):
        """
        Prefix: ``progress clear``
        
        Reset progress tracking
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'progress clear'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def progress_json(self):
        """
        Prefix: ``progress json``
        
        Show machine readable progress information
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'progress json'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def prometheus_file_sd_config(self):
        """
        Prefix: ``prometheus file_sd_config``
        
        Return file_sd compatible prometheus config for mgr cluster
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'prometheus file_sd_config'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def quorum(self, quorumcmd: str):
        """
        Prefix: ``quorum``
        
        enter or exit quorum
        
        module=mon perm=rw flags=
        
        :param quorumcmd: CephChoices strings=enter|exit
        """
        prefix = 'quorum'
        _args = {'prefix': prefix, 'quorumcmd': quorumcmd}
        return self._mon_command(_args)
    
    def quorum_status(self):
        """
        Prefix: ``quorum_status``
        
        report status of monitor quorum
        
        module=mon perm=r flags=
        """
        prefix = 'quorum_status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def rbd_perf_image_counters(self, pool_spec: str=None, sort_by: str=None):
        """
        Prefix: ``rbd perf image counters``
        
        Retrieve current RBD IO performance counters
        
        module=mgr perm=r flags=mgr
        
        :param pool_spec:
        :param sort_by: CephChoices strings=write_ops|write_bytes|write_latenc
            y|read_ops|read_bytes|read_latency
        """
        prefix = 'rbd perf image counters'
        _args = {'prefix': prefix, 'pool_spec': pool_spec, 'sort_by': sort_by}
        return self._mon_command(_args)
    
    def rbd_perf_image_stats(self, pool_spec: str=None, sort_by: str=None):
        """
        Prefix: ``rbd perf image stats``
        
        Retrieve current RBD IO performance stats
        
        module=mgr perm=r flags=mgr
        
        :param pool_spec:
        :param sort_by: CephChoices strings=write_ops|write_bytes|write_latenc
            y|read_ops|read_bytes|read_latency
        """
        prefix = 'rbd perf image stats'
        _args = {'prefix': prefix, 'pool_spec': pool_spec, 'sort_by': sort_by}
        return self._mon_command(_args)
    
    def report(self, tags: List[str]=None):
        """
        Prefix: ``report``
        
        report full status of cluster, optional title tag strings
        
        module=mon perm=r flags=
        
        :param tags:
        """
        prefix = 'report'
        _args = {'prefix': prefix, 'tags': tags}
        return self._mon_command(_args)
    
    @deprecated
    def scrub(self):
        """
        Prefix: ``scrub``
        
        scrub the monitor stores
        
        module=mon perm=rw flags=deprecated
        """
        prefix = 'scrub'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def service_dump(self):
        """
        Prefix: ``service dump``
        
        dump service map
        
        module=service perm=r flags=mgr
        """
        prefix = 'service dump'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def service_status(self):
        """
        Prefix: ``service status``
        
        dump service state
        
        module=service perm=r flags=mgr
        """
        prefix = 'service status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def smart(self, devid: str=None):
        """
        Prefix: ``smart``
        
        Query health metrics for underlying device
        
        module=mon perm=rw flags=hidden
        
        :param devid:
        """
        prefix = 'smart'
        _args = {'prefix': prefix, 'devid': devid}
        return self._mon_command(_args)
    
    def ssh_clear_ssh_config(self):
        """
        Prefix: ``ssh clear-ssh-config``
        
        Clear the ssh_config file
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'ssh clear-ssh-config'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def ssh_set_ssh_config(self):
        """
        Prefix: ``ssh set-ssh-config``
        
        Set the ssh_config file (use -i <ssh_config>)
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'ssh set-ssh-config'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def status(self):
        """
        Prefix: ``status``
        
        show cluster status
        
        module=mon perm=r flags=
        """
        prefix = 'status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    @deprecated
    def sync_force(self, yes_i_really_mean_it: bool=None,
                   i_know_what_i_am_doing: bool=None):
        """
        Prefix: ``sync force``
        
        force sync of and clear monitor store
        
        module=mon perm=rw flags=no_forward, deprecated
        
        :param yes_i_really_mean_it: CephBool
        :param i_know_what_i_am_doing: CephBool
        """
        prefix = 'sync force'
        _args = {'prefix': prefix, 'yes_i_really_mean_it': yes_i_really_mean_it,
                 'i_know_what_i_am_doing': i_know_what_i_am_doing}
        return self._mon_command(_args)
    
    def telegraf_config_set(self, key: str, value: str):
        """
        Prefix: ``telegraf config-set``
        
        Set a configuration value
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        :param value:
        """
        prefix = 'telegraf config-set'
        _args = {'prefix': prefix, 'key': key, 'value': value}
        return self._mon_command(_args)
    
    def telegraf_config_show(self):
        """
        Prefix: ``telegraf config-show``
        
        Show current configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'telegraf config-show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telegraf_send(self):
        """
        Prefix: ``telegraf send``
        
        Force sending data to Telegraf
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'telegraf send'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telemetry_off(self):
        """
        Prefix: ``telemetry off``
        
        Disable telemetry reports from this cluster
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'telemetry off'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telemetry_on(self):
        """
        Prefix: ``telemetry on``
        
        Enable telemetry reports from this cluster
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'telemetry on'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telemetry_send(self):
        """
        Prefix: ``telemetry send``
        
        Force sending data to Ceph telemetry
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'telemetry send'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telemetry_show(self):
        """
        Prefix: ``telemetry show``
        
        Show last report or report to be sent
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'telemetry show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def telemetry_status(self):
        """
        Prefix: ``telemetry status``
        
        Show current configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'telemetry status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def tell(self, target: str, args: List[str]):
        """
        Prefix: ``tell``
        
        send a command to a specific daemon
        
        module=mon perm=rw flags=
        
        :param target: CephName
        :param args:
        """
        prefix = 'tell'
        _args = {'prefix': prefix, 'target': target, 'args': args}
        return self._mon_command(_args)
    
    def time_sync_status(self):
        """
        Prefix: ``time-sync-status``
        
        show time sync status
        
        module=mon perm=r flags=
        """
        prefix = 'time-sync-status'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def version(self):
        """
        Prefix: ``version``
        
        show mon daemon version
        
        module=mon perm=r flags=no_forward
        """
        prefix = 'version'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def versions(self):
        """
        Prefix: ``versions``
        
        check running versions of ceph daemons
        
        module=mon perm=r flags=
        """
        prefix = 'versions'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def zabbix_config_set(self, key: str, value: str):
        """
        Prefix: ``zabbix config-set``
        
        Set a configuration value
        
        module=mgr perm=rw flags=mgr
        
        :param key:
        :param value:
        """
        prefix = 'zabbix config-set'
        _args = {'prefix': prefix, 'key': key, 'value': value}
        return self._mon_command(_args)
    
    def zabbix_config_show(self):
        """
        Prefix: ``zabbix config-show``
        
        Show current configuration
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'zabbix config-show'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def zabbix_discovery(self):
        """
        Prefix: ``zabbix discovery``
        
        Discovering Zabbix data
        
        module=mgr perm=r flags=mgr
        """
        prefix = 'zabbix discovery'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
    
    def zabbix_send(self):
        """
        Prefix: ``zabbix send``
        
        Force sending data to Zabbix
        
        module=mgr perm=rw flags=mgr
        """
        prefix = 'zabbix send'
        _args = {'prefix': prefix, }
        return self._mon_command(_args)
